%==========================================================================

% Code for the replication of the paper "Unconventional Monetary Policy, 
% Fiscal Side Effects and Euro Area (Im)balances", Journal of the European
% Economic Association, by Michael Hachula, Michele Piffer and Malte Rieth

% Michele Piffer, m.b.piffer@gmail.com
% https://sites.google.com/site/michelepiffereconomics/
% October 2018, Queen Mary, University of London

%==========================================================================


close all

Boot = 500;

year_data     = kron((1999:1:2016)',ones(12,1));
month_data    = kron(ones(2016 - 1999+1,1),(1:1:12)');
T_data        = length(year_data);
timeaxis_data = [year_data(1) : 1/12 : year_data(end)+1-1/12]';
assert( length(timeaxis_data) == T_data); 

load('..\Temporary\Temporary_ConstructedProxy_withdailybetas')

% do_full_computation = 1;
do_full_computation = 0; 

if do_full_computation == 1

    %% IMPORT EURO VARIABLES
    step_data = xlsread('..\Data\Data_monthly_Euro_zone.xlsx', 'Rearranged_extended', 'B2:M325'); % done
    assert( size(step_data,1) == (2016 - 1990 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Euro_zone.xlsx', 'Legend', 'D2:D13'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Euro_zone.xlsx', 'Legend', 'E2:E13'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Euro_zone.xlsx', 'Legend', 'H2:H13'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Euro_zone.xlsx', 'Legend', 'F2:F13'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Euro_zone.xlsx', 'Legend', 'G2:G13'); 

    % Take only the part from 1999 to 2016, included
    from = (1998 - 1990 + 1)*12+1;
    step_data = step_data(from:end,:);
    assert( size(step_data,1) == T_data ) 

    % Convert certain variables into logs
    step_convert_to_logs = [2:6 8:12];
    step_data_fullnames(step_convert_to_logs);
    string1 = ', log';
    for step1 = 1:length(step_convert_to_logs)   
        step2 = step_convert_to_logs(step1);

        step_data(:,step2)             = log(step_data(:,step2));   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2),   string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
        step_data_transformIRFs(step2) = 100;
        step_data_labelIRFs(step2)     = cellstr(char('%'));
    end


    % Append to the existing data
    data_monthly_all     = step_data;
    fullnames_data       = step_data_fullnames;
    betternames_data     = step_data_betternames;
    region_data          = step_data_region;
    transformIRFs_data   = step_data_transformIRFs;
    labelIRFs_data       = step_data_labelIRFs;
    first_frequency_data = cellstr(repmat('monthly', size(step_data,2), 1));
    data_rswidentif      = NaN*ones(size(step_data));

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs  


    %% IMPORT COUNTRY SPECIFIC DATA on IP and CPI
    step_data = xlsread('..\Data\Data_monthly_IP_CPI.xlsx', 'Rearranged', 'B2:AI217'); % done
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_IP_CPI.xlsx', 'Legend', 'D2:D35'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_IP_CPI.xlsx', 'Legend', 'E2:E35'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_IP_CPI.xlsx', 'Legend', 'H2:H35'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_IP_CPI.xlsx', 'Legend', 'F2:F35'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_IP_CPI.xlsx', 'Legend', 'G2:G35'); 

    % Convert certain variables into logs
    step_convert_to_logs = [1:1:size(step_data,2)];
    string1 = ', log';
    for step1 = 1:length(step_convert_to_logs)   
        step2 = step_convert_to_logs(step1);

        step_data(:,step2)             = log(step_data(:,step2));   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2), string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
        step_data_transformIRFs(step2) = 100;
        step_data_labelIRFs(step2)     = cellstr(char('%'));
    end
     

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)                                        
    assert(size(data_rswidentif,2)      == k)                                         

    
    % store logCPI, to be used to deflate later
    step_whichvariables      = [11, 30:1:46];
    assert( strcmp(fullnames_data(step_whichvariables(1)), 'EA CPI, sa, log')  == 1 )
    assert( strcmp(fullnames_data(step_whichvariables(2)), 'GER CPI, sa, log') == 1 )

    logCPI_all_fullnames     = fullnames_data(step_whichvariables);
    logCPI_all_betternames   = betternames_data(step_whichvariables);
    logCPI_all               = data_monthly_all(:,step_whichvariables);
    logCPI_all_region        = region_data(step_whichvariables);
    logCPI_all_transformIRFs = transformIRFs_data(step_whichvariables);
    logCPI_all_labelIRFs     = labelIRFs_data(step_whichvariables);

    logCPI_all_fullnames     = [cellstr(logCPI_all_fullnames);    char('EA19 CPI, sa log')]; 
    logCPI_all_betternames   = [cellstr(logCPI_all_betternames);  char('Consumer prices')]; 
    logCPI_all               = [logCPI_all,                 logCPI_all(:,1)];
    logCPI_all_region        = [cellstr(logCPI_all_region); char('EA19')];
    logCPI_all_transformIRFs = [logCPI_all_transformIRFs;   100];
    logCPI_all_labelIRFs     = [logCPI_all_labelIRFs;       '%'];

    logCPI_all_fullnames     = [cellstr(logCPI_all_fullnames);    char('EA11 CPI, sa log')]; 
    logCPI_all_betternames   = [cellstr(logCPI_all_betternames);  char('Consumer prices')]; 
    logCPI_all               = [logCPI_all,                 logCPI_all(:,1)];
    logCPI_all_region        = [cellstr(logCPI_all_region); char('EA11')];
    logCPI_all_transformIRFs = [logCPI_all_transformIRFs;   100];
    logCPI_all_labelIRFs     = [logCPI_all_labelIRFs;       '%'];

    clear step_whichvariables


    % Create a measure of dispersion over IP and CPI
    step_data_diff = [NaN*ones(12,size(step_data,2)); (step_data(13:end,:)-step_data(1:end-12,:))*100]; % percentage variation across time, approximated with log diff 
    step3 = size(step_data,2)/2;
    step_data_fullnames(1:step3);
    step_data_fullnames(step3+1:end);


    % figure(9898)
    % for i = 1:size(step_data_diff,2)/2
    %    subplot(ceil(size(step_data_diff,2)/3)/2,3,i)
    %    plot(step_data_diff(:,i))
    %    title(step_data_fullnames(i))
    % end

    crosssec_dispersion_IP  = NaN*ones(T_data,1);
    crosssec_dispersion_CPI = NaN*ones(T_data,1);
    for t = 2:T_data
        % IP
        step4 = step_data_diff(t,1:step3);
        step5 = isnan(step4);
        step6 = step4(step5==0);
        crosssec_dispersion_IP(t) = std(step6);

        % CPI
        step4 = step_data_diff(t,step3+1:end);
        step5 = isnan(step4);
        step6 = step4(step5==0);
        crosssec_dispersion_CPI(t) = std(step6);    
    end

    % figure(1)
    % subplot(1,2,1)
    % plot(crosssec_dispersion_IP, 'r'), hold on
    % subplot(1,2,2)
    % plot(crosssec_dispersion_CPI, 'r'), hold on


    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      crosssec_dispersion_IP, crosssec_dispersion_CPI];
    fullnames_data       = [fullnames_data;        char('EA IP cross sectional dispersion'); char('EA CPI cross sectional dispersion')];
    betternames_data     = [betternames_data;      char('IP dispersion'); char('CPI dispersion')];
    region_data          = [region_data;           char('EA'); char('EA')];
    transformIRFs_data   = [transformIRFs_data;    ones(2,1)];
    labelIRFs_data       = [labelIRFs_data;        char('% points'); char('% points')];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', 2, 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(T_data,2)];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         


    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs 
    clear crosssec_dispersion_IP crosssec_dispersion_CPI 


    %% IMPORT EURO AREA VARIABLES on CREDIT
    step_data = xlsread('..\Data\Data_monthly_Credit.xlsx', 'Rearranged', 'B3:G232'); % done
    assert( size(step_data,1) == (2015 - 1998 + 1)*12 + 3 + 11) 

    % drop some observations and add NaN for the missing months, given that it covers the period 1997M10 - 2016M11
    step_data = [step_data(12+3+1:end,:); NaN*ones(1, size(step_data, 2))]; 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Credit.xlsx', 'Legend', 'D2:D7'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Credit.xlsx', 'Legend', 'E2:E7'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Credit.xlsx', 'Legend', 'H2:H7'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Credit.xlsx', 'Legend', 'F2:F7'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Credit.xlsx', 'Legend', 'G2:G7'); 

    % Convert certain variables into logs
    step_convert_to_logs = [4, 5, 6];
    step_data_fullnames(step_convert_to_logs);
    string1 = ', log';
    for step1 = 1:length(step_convert_to_logs)   
        step2 = step_convert_to_logs(step1);

        step_data(:,step2)             = log(step_data(:,step2));   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2), string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
        step_data_transformIRFs(step2) = 100;
        step_data_labelIRFs(step2)     = cellstr(char('%'));
    end

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs


    %% IMPORT EURO AREA VARIABLES on SELECTED INTEREST RATES
    step_data = xlsread('..\Data\Data_monthly_Lending.xlsx', 'Rearranged', 'B3:E216'); % done
    assert( size(step_data,1) == (2015 - 2000 + 1)*12 + 11) 

    % drop some observations and add NaN for the missing months, given that it covers the period 2000M1 - 2016M11
    step_data = [NaN*ones(12, size(step_data, 2)); step_data; NaN*ones(1, size(step_data, 2))]; 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Lending.xlsx', 'Legend', 'D2:D5'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Lending.xlsx', 'Legend', 'E2:E5'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Lending.xlsx', 'Legend', 'H2:H5'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Lending.xlsx', 'Legend', 'F2:F5'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Lending.xlsx', 'Legend', 'G2:G5'); 

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs


    %% IMPORT COUNTRY SPECIFIC and EA DATA on UNEMPLOYMENT RATE
    step_data = xlsread('..\Data\Data_monthly_Employment.xlsx', 'Rearranged', 'B2:V217'); % done
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Employment.xlsx', 'Legend', 'D2:D22'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Employment.xlsx', 'Legend', 'E2:E22'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Employment.xlsx', 'Legend', 'H2:H22'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Employment.xlsx', 'Legend', 'F2:F22'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Employment.xlsx', 'Legend', 'G2:G22'); 


    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    
    % Create a measure of dispersion over unemployment
    step3 = 3;
    step_data_fullnames(step3:end)

    crosssec_dispersion_unemployment  = NaN*ones(T_data,1);
    for t = 1:T_data
        step4 = step_data(t,step3:end);
        step5 = isnan(step4);
        step6 = step4(step5==0);
        if length(step6) >= 4 % for the last observation we only have data for Ireland, hence no dispersion can be computed
            crosssec_dispersion_unemployment(t) = std(step6);
        end
    end

    % figure(34234)
    % for i = 1:size(step_data_fullnames,1)-2
    %    subplot(ceil((size(step_data_fullnames,1)-2)/2), 2, i) 
    %    
    %    plot(step_data(:,2+i))
    %    title(step_data_fullnames(2+i))
    % end
    % subplot(ceil((size(step_data_fullnames,1)-2)/2), 2, size(step_data_fullnames,1)-1) 
    % plot(crosssec_dispersion_unemployment)


    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      crosssec_dispersion_unemployment];
    fullnames_data       = [fullnames_data;        char('EA Unemployment cross sectional dispersion')];
    betternames_data     = [betternames_data;      char('Unemployment dispersion')];
    region_data          = [region_data;           char('EA')];
    transformIRFs_data   = [transformIRFs_data;    ones(1,1)];
    labelIRFs_data       = [labelIRFs_data;        char('% points')];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', 1, 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(T_data,1)];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs 


    %% IMPORT COUNTRY SPECIFIC DATA on NET TRADE vs GERMANY
    step_data = xlsread('..\Data\Data_monthly_Foreign_trade.xlsx', 'Rearranged', 'B2:S186'); % done
    assert( size(step_data,1) == (2015 - 2002 + 1)*12 + 7 + 10) 

    % add NaN for the missing months, given that it covers the period 2001M6 - 2016M10
    step_data = [NaN*ones(12*2 + 5, size(step_data, 2)); step_data; NaN*ones(2, size(step_data, 2))]; 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Foreign_trade.xlsx', 'Legend', 'D2:D19'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Foreign_trade.xlsx', 'Legend', 'E2:E19'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Foreign_trade.xlsx', 'Legend', 'H2:H19'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Foreign_trade.xlsx', 'Legend', 'F2:F19'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Foreign_trade.xlsx', 'Legend', 'G2:G19'); 

    % Convert from thousands to milions of euros
    step_convert_to_logs = [1:1:size(step_data,2)];
    string1 = ', milion euros';
    for step1 = 1:length(step_convert_to_logs)   
        step2 = step_convert_to_logs(step1);

        step_data(:,step2)             = step_data(:,step2)/1000;   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2), string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
        step_data_labelIRFs(step2)     = cellstr(char('Mill. euros'));
    end

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs


    %% IMPORT COUNTRY SPECIFIC and EA DATA on GOVERNMENT VARIABLES, part 1
    step_data = xlsread('..\Data\Data_monthly_Gov_expend_detail.xlsx', 'Rearranged', 'B2:CG217'); % done
    assert( size(step_data,1) == (2015 - 2000 + 1)*12 + 10 + 6) 

    % add NaN for the missing months, given that it covers the period 1999M3 - 2016M6
    step_data = [NaN*ones(2, size(step_data, 2)); step_data; NaN*ones(6, size(step_data, 2))]; 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Gov_expend_detail.xlsx', 'Legend', 'D2:D85'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Gov_expend_detail.xlsx', 'Legend', 'E2:E85'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Gov_expend_detail.xlsx', 'Legend', 'H2:H85'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Gov_expend_detail.xlsx', 'Legend', 'F2:F85'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Gov_expend_detail.xlsx', 'Legend', 'G2:G85'); 

    % Convert certain variables into logs
    step_convert_to_logs = [1:1:44, 64:1:84];
    step_data_fullnames(step_convert_to_logs)
    string1 = ', log';
    for step1 = 1:length(step_convert_to_logs)   
        step2 = step_convert_to_logs(step1);

        step_data(:,step2)             = log(step_data(:,step2));   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2), string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
        step_data_transformIRFs(step2) = 100;
        step_data_labelIRFs(step2)     = cellstr(char('%'));
    end

    % Convert certain variables into real terms, using the corresponding CPI
    step_convert_to_real = [1:1:42, 64:1:84];
    step_data_fullnames(step_convert_to_real)
    step_convert_to_real = setdiff(step_convert_to_real, [ 5, 26, 68]); % drop Estonia, sinc we do not have CPI for Estonia
    step_convert_to_real = setdiff(step_convert_to_real, [14, 35, 77]); % drop Luxembourg, sinc we do not have CPI for Luxembourg
    string1 = ', real';
    for step1 = 1:length(step_convert_to_real)   
        step2 = step_convert_to_real(step1);
        step_data_fullnames(step2);

        step3 = find(strcmp(logCPI_all_region, step_data_region(step2)));

        step_data(:,step2)             = step_data(:,step2) - logCPI_all(:,step3);   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2), string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
    end

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs 


    %% IMPORT COUNTRY SPECIFIC and EA DATA on GOVERNMENT VARIABLES, part 2
    step_data = xlsread('..\Data\Data_monthly_Gov_expend_total.xlsx', 'Rearranged', 'B2:CG217'); % done
    assert( size(step_data,1) == (2015 - 2000 + 1)*12 + 10 + 6) 

    % add NaN for the missing months, given that it covers the period 1999M3 - 2016M6
    step_data = [NaN*ones(2, size(step_data, 2)); step_data; NaN*ones(6, size(step_data, 2))]; 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Gov_expend_total.xlsx', 'Legend', 'D2:D85'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Gov_expend_total.xlsx', 'Legend', 'E2:E85'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Gov_expend_total.xlsx', 'Legend', 'H2:H85'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Gov_expend_total.xlsx', 'Legend', 'F2:F85'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Gov_expend_total.xlsx', 'Legend', 'G2:G85'); 

    % Convert certain variables into logs
    step_convert_to_logs = [1:1:44, 64:1:84];
    step_data_fullnames(step_convert_to_logs)
    string1 = ', log';
    for step1 = 1:length(step_convert_to_logs)   
        step2 = step_convert_to_logs(step1);

        step_data(:,step2)             = log(step_data(:,step2));   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2), string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
        step_data_transformIRFs(step2) = 100;
        step_data_labelIRFs(step2)     = cellstr(char('%'));
    end

    % Convert certain variables into real terms, using the corresponding CPI
    step_convert_to_real = [1:1:42, 64:1:84];
    step_convert_to_real = setdiff(step_convert_to_real, [ 5, 26, 68]); % drop Estonia, since we do not have CPI 
    step_convert_to_real = setdiff(step_convert_to_real, [14, 35, 77]); % drop Luxembourg, since we do not have CPI 
    string1 = ', real';
    for step1 = 1:length(step_convert_to_real)   
        step2 = step_convert_to_real(step1);
        step_data_fullnames(step2);

        step3 = find(strcmp(logCPI_all_region, step_data_region(step2)));

        step_data(:,step2)             = step_data(:,step2) - logCPI_all(:,step3);   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2), string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
    end

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs


    %% IMPORT COUNTRY SPECIFIC and EA DATA on CORE CONSUMER PRICES
    step_data = xlsread('..\Data\Data_monthly_Core_consumer_prices.xlsx', 'Rearranged', 'B2:W217'); % done
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Core_consumer_prices.xlsx', 'Legend', 'D2:D23'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Core_consumer_prices.xlsx', 'Legend', 'E2:E23'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Core_consumer_prices.xlsx', 'Legend', 'H2:H23'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Core_consumer_prices.xlsx', 'Legend', 'F2:F23'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Core_consumer_prices.xlsx', 'Legend', 'G2:G23'); 

    % Convert certain variables into logs
    step_convert_to_logs = [1:1:size(step_data,2)];
    string1 = ', log';
    for step1 = 1:length(step_convert_to_logs)   
        step2 = step_convert_to_logs(step1);

        step_data(:,step2)             = log(step_data(:,step2));   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2), string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
        step_data_transformIRFs(step2) = 100;
        step_data_labelIRFs(step2)     = cellstr(char('%'));
    end

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs


    %% IMPORT COUNTRY SPECIFIC and EA DATA on DEBT to GDP ratios
    step_data = xlsread('..\Data\Data_monthly_Debt_to_gdp.xlsx', 'Rearranged', 'B2:X212'); % done
    assert( size(step_data,1) == (2015 - 2000 + 1)*12 + 10 + 9) 

    % add NaN for the missing months, given that it covers the period 1999M3 - 2016M9
    step_data = [NaN*ones(2, size(step_data, 2)); step_data; NaN*ones(3, size(step_data, 2))]; 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Debt_to_gdp.xlsx', 'Legend', 'D2:D24'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Debt_to_gdp.xlsx', 'Legend', 'E2:E24'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Debt_to_gdp.xlsx', 'Legend', 'H2:H24'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Debt_to_gdp.xlsx', 'Legend', 'F2:F24'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Debt_to_gdp.xlsx', 'Legend', 'G2:G24'); 

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs


    %% IMPORT SOME COUNTRY SPECIFIC and EA DATA on INFLATION EXPECTATIONS
    step_data = xlsread('..\Data\Data_monthly_Inflation_expectations.xlsx', 'Rearranged', 'B2:F217'); % done
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Inflation_expectations.xlsx', 'Legend', 'D2:D6'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Inflation_expectations.xlsx', 'Legend', 'E2:E6'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Inflation_expectations.xlsx', 'Legend', 'H2:H6'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Inflation_expectations.xlsx', 'Legend', 'F2:F6'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Inflation_expectations.xlsx', 'Legend', 'G2:G6'); 

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs


    %% IMPORT EA data on Deficis
    step_data = xlsread('..\Data\Data_monthly_Deficit.xlsx', 'Rearranged', 'B2:F217'); % done
    assert( size(step_data,1) == (2015 - 2003 + 1)*12 + 5) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Deficit.xlsx', 'Legend', 'D2:D2'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Deficit.xlsx', 'Legend', 'E2:E2'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Deficit.xlsx', 'Legend', 'H2:H2'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Deficit.xlsx', 'Legend', 'F2:F2'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Deficit.xlsx', 'Legend', 'G2:G2'); 

    % add NaN for the missing months, given that it covers the period 2003M1 - 2015M5
    step_data = [NaN*ones(4*12, size(step_data, 2)); step_data; NaN*ones(7, size(step_data, 2))]; 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs


    %% COMPUTE log CPI DIFFERENTIALS AGAINST GERMANY
    step_convert_difffromDE = [3:1:18];
    step_convert_DE         = find(strcmp(logCPI_all_fullnames, 'GER CPI, sa, log'));

    step_data = logCPI_all(:,step_convert_difffromDE) - ...
                kron( ones(1,length(step_convert_difffromDE)) , logCPI_all(:,step_convert_DE));

    step_data_fullnames     = strcat(logCPI_all_fullnames(step_convert_difffromDE), ', minus GER CPI, sa, log'); 
    step_data_betternames   = strcat(logCPI_all_betternames(step_convert_difffromDE), ', minus GER'); 
    step_data_region        = logCPI_all_region(step_convert_difffromDE);
    step_data_transformIRFs = logCPI_all_transformIRFs(step_convert_difffromDE);
    step_data_labelIRFs     = logCPI_all_labelIRFs(step_convert_difffromDE);

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs                                   


    %% IMPORT CREDIT SPREADS
    step_data = xlsread('..\Data\Data_monthly_GM_credit_spreads.xlsx', 'Rearranged', 'B2:K219'); 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12 + 2) 

    % keep only part until 2016M12, given that it covers the period 1999M1 until 2017M2
    step_data = step_data(1:end-2,:); 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_GM_credit_spreads.xlsx', 'Legend', 'D2:D11'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_GM_credit_spreads.xlsx', 'Legend', 'E2:E11'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_GM_credit_spreads.xlsx', 'Legend', 'H2:H11'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_GM_credit_spreads.xlsx', 'Legend', 'F2:F11'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_GM_credit_spreads.xlsx', 'Legend', 'G2:G11'); 

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs

    %% IMPORT INTERPOLATED GDP
    step_data = xlsread('..\Data\Data_monthly_GDP_interpolated.xlsx', 'Rearranged', 'B2:V217'); 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_GDP_interpolated.xlsx', 'Legend', 'D2:D22'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_GDP_interpolated.xlsx', 'Legend', 'E2:E22'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_GDP_interpolated.xlsx', 'Legend', 'H2:H22'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_GDP_interpolated.xlsx', 'Legend', 'F2:F22'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_GDP_interpolated.xlsx', 'Legend', 'G2:G22'); 


    % Convert certain variables into logs
    step_convert_to_logs = [1:1:size(step_data,2)];
    string1 = ', log';
    for step1 = 1:length(step_convert_to_logs)   
        step2 = step_convert_to_logs(step1);

        step_data(:,step2)             = log(step_data(:,step2));   
        step_data_fullnames(step2)     = strcat(step_data_fullnames(step2),   string1);
        step_data_betternames(step2)   = strcat(step_data_betternames(step2));
        step_data_transformIRFs(step2) = 100;
        step_data_labelIRFs(step2)     = cellstr(char('%'));
    end

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs

    
    %% IMPORT DATA ON EUROPEAN UNION NET EXPORTS VERSUS REST OF THE UNION AS A RATIO OF GDP
         
    step_data = xlsread('..\Data\Data_monthly_Trade.xlsx', 'trade_by_gdp final', 'B2:T217'); 
    assert( size(step_data,1) == (2016 - 1999 + 1)*12) 

    [~,~,step_data_fullnames]   = xlsread('..\Data\Data_monthly_Trade.xlsx', 'Legend', 'D2:D20'); 
    [~,~,step_data_betternames] = xlsread('..\Data\Data_monthly_Trade.xlsx', 'Legend', 'E2:E20'); 
    [~,~,step_data_region]      = xlsread('..\Data\Data_monthly_Trade.xlsx', 'Legend', 'H2:H20'); 
    step_data_transformIRFs     = xlsread('..\Data\Data_monthly_Trade.xlsx', 'Legend', 'F2:F20'); 
    [~,~,step_data_labelIRFs]   = xlsread('..\Data\Data_monthly_Trade.xlsx', 'Legend', 'G2:G20'); 


    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data];
    fullnames_data       = [fullnames_data;        step_data_fullnames];
    betternames_data     = [betternames_data;      step_data_betternames];
    region_data          = [region_data;           step_data_region];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    % Compute average absolute trade balance, weighted by country GDP (ADDED FOR THIRD SUBMISSION)    
    step_weigths_countries            = xlsread('..\Data\Data_daily_Weights.xlsx', 'WeightsFinal', 'B1:B19'); 
    [~,~,step_weigths_countriesnames] = xlsread('..\Data\Data_daily_Weights.xlsx', 'WeightsFinal', 'A1:A19'); 
    assert(length(step_weigths_countries) == size(step_data,2)) 
    step_weigths_countries_reordered  = NaN*ones(size(step_data,2),1);
    for i = 1:size(step_data,2)
        step_weigths_countries_reordered(i) = step_weigths_countries(find(strcmp(step_weigths_countriesnames, step_data_region(i))));
    end
    
    assert( abs(sum(step_weigths_countries_reordered) - 1) < 0.0001)
    
    step_data2 = abs(step_data); % absolute value
    step_data3 = NaN*ones(size(step_data,1),1);
    for i = 1:size(step_data,1)
        % weighted by GDP
        step_available = step_data2(i,isnan(step_data2(i,:))==0); 
        step_data3(i)  = step_weigths_countries_reordered(isnan(step_data2(i,:))==0)'*step_available'/sum(step_weigths_countries_reordered(isnan(step_data2(i,:))==0));        
    end
        
    step_data_fullnames3     = char('Average absolute trade within EA19, %, weighted by GDP'); 
    step_data_betternames3   = char('Average absolute trade');
    step_data_region3        = char('EA19');
    step_data_transformIRFs3 = 1;
    step_data_labelIRFs3     = char('% points');
     
    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step_data3];
    fullnames_data       = [fullnames_data;        step_data_fullnames3];
    betternames_data     = [betternames_data;      step_data_betternames3];
    region_data          = [region_data;           step_data_region3];
    transformIRFs_data   = [transformIRFs_data;    step_data_transformIRFs3];
    labelIRFs_data       = [labelIRFs_data;        step_data_labelIRFs3];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', size(step_data3,2), 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(size(step_data3))];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         
     
    clear step_data step_data_fullnames step_data_betternames step_data_region step_data_transformIRFs step_data_labelIRFs
    clear step_data3 step_data_fullnames3 step_data_betternames3 step_data_region3 step_data_transformIRFs3 step_data_labelIRFs3  
    
    
    %% Country classifications
    
    countries_name = unique(region_data);
    countries_n    = length(countries_name);

    countries_label = countries_name;
    countries_label(find(strcmp(countries_name, 'Austria'))) = cellstr(char('AUT'));
    countries_label(find(strcmp(countries_name, 'Belgium'))) = cellstr(char('BEL'));
    countries_label(find(strcmp(countries_name, 'Cyprus')))  = cellstr(char('CYP'));
    countries_label(find(strcmp(countries_name, 'EA')))      = cellstr(char('EA'));
    countries_label(find(strcmp(countries_name, 'Estonia'))) = cellstr(char('EST'));
    countries_label(find(strcmp(countries_name, 'Finland'))) = cellstr(char('FIN'));
    countries_label(find(strcmp(countries_name, 'France')))  = cellstr(char('FRA'));
    countries_label(find(strcmp(countries_name, 'Germany'))) = cellstr(char('GER'));
    countries_label(find(strcmp(countries_name, 'Greece')))  = cellstr(char('GRE'));
    countries_label(find(strcmp(countries_name, 'Ireland'))) = cellstr(char('IRE'));
    countries_label(find(strcmp(countries_name, 'Italy')))   = cellstr(char('ITA'));
    countries_label(find(strcmp(countries_name, 'Latvia')))  = cellstr(char('LAT'));
    countries_label(find(strcmp(countries_name, 'Lithuania')))  = cellstr(char('LIT'));
    countries_label(find(strcmp(countries_name, 'Luxembourg'))) = cellstr(char('LUX'));
    countries_label(find(strcmp(countries_name, 'Malta')))   = cellstr(char('MAL'));
    countries_label(find(strcmp(countries_name, 'Portugal')))   = cellstr(char('POR'));
    countries_label(find(strcmp(countries_name, 'Slovakia')))   = cellstr(char('SVK'));
    countries_label(find(strcmp(countries_name, 'Slovenia')))   = cellstr(char('SVN'));
    countries_label(find(strcmp(countries_name, 'Spain')))   = cellstr(char('SPA'));
    countries_label(find(strcmp(countries_name, 'The Netherlands'))) = cellstr(char('NLD'));

    countries_classif               = NaN*ones(countries_n,5);
    countries_classif_summary       = [];
    
    % 1) %%% average exporters and average importers within the EU
    
    % select the list of variables used in Figure 7
    step1 = NaN*ones(18,1);
    step1(1) = find(strcmp(fullnames_data, 'AUT trade within EA19 in %'));
    step1(2) = find(strcmp(fullnames_data, 'BEL trade within EA19 in %'));
    step1(3) = find(strcmp(fullnames_data, 'CYP trade within EA19 in %'));
    step1(4) = find(strcmp(fullnames_data, 'EST trade within EA19 in %'));
    step1(5) = find(strcmp(fullnames_data, 'FIN trade within EA19 in %'));
    step1(6) = find(strcmp(fullnames_data, 'FRA trade within EA19 in %'));
    step1(7) = find(strcmp(fullnames_data, 'GER trade within EA19 in %'));
    step1(8) = find(strcmp(fullnames_data, 'GRE trade within EA19 in %'));
    step1(9) = find(strcmp(fullnames_data, 'IRE trade within EA19 in %'));
    step1(10) = find(strcmp(fullnames_data, 'ITA trade within EA19 in %'));
    step1(11) = find(strcmp(fullnames_data, 'LAT trade within EA19 in %'));
    step1(12) = find(strcmp(fullnames_data, 'LIT trade within EA19 in %'));
    step1(13) = find(strcmp(fullnames_data, 'LUX trade within EA19 in %'));
    step1(14) = find(strcmp(fullnames_data, 'MAL trade within EA19 in %'));
    step1(15) = find(strcmp(fullnames_data, 'PRT trade within EA19 in %'));
    step1(16) = find(strcmp(fullnames_data, 'SVN trade within EA19 in %'));
    step1(17) = find(strcmp(fullnames_data, 'SPA trade within EA19 in %'));
    step1(18) = find(strcmp(fullnames_data, 'NLD trade within EA19 in %'));
    
    
    step2 = data_monthly_all(:,step1);
    step4 = NaN*ones(18,1);
    for i = 1:length(step1)
        step3 = step2(isnan(step2(:,i))==0,i);
        step4(i) = mean(step3);
    end

    step5 = region_data(step1);
    step6 = step5(step4 >= 0)
    step7 = step5(step4 <= 0)
    

    classif_number = 1;
    for i = 1:length(step6)
        j = find(strcmp(countries_name, step6(i))); 
        countries_classif(j,classif_number) = 1;
    end
    for i = 1:length(step7)
        j = find(strcmp(countries_name, step7(i))); 
        countries_classif(j,classif_number) = -1;
    end
    countries_classif_summary = [countries_classif_summary; cellstr(char('Net exporter (1) or net importer (-1) within the EU, o/wise NaN'))];

    
    % %%% 2) core vs periphery countries, following the classification used to construct the instruments
    step1_core = NaN*ones(6,1);
    step1_core(1) = find(strcmp(countries_name, 'Austria'));
    step1_core(2) = find(strcmp(countries_name, 'Finland'));
    step1_core(3) = find(strcmp(countries_name, 'France'));
    step1_core(4) = find(strcmp(countries_name, 'Germany'));
    step1_core(5) = find(strcmp(countries_name, 'The Netherlands'));
    % add also the ones that were excluded from the construction of the instrument for data availability, since they might have data on trade balance
    step1_core(6) = find(strcmp(countries_name, 'Luxembourg'));
    
    step1_periph = NaN*ones(13,1);
    step1_periph(1) = find(strcmp(countries_name, 'Belgium'));
    step1_periph(2) = find(strcmp(countries_name, 'Greece'));
    step1_periph(3) = find(strcmp(countries_name, 'Ireland'));
    step1_periph(4) = find(strcmp(countries_name, 'Italy'));
    step1_periph(5) = find(strcmp(countries_name, 'Latvia'));
    step1_periph(6) = find(strcmp(countries_name, 'Malta'));
    step1_periph(7) = find(strcmp(countries_name, 'Portugal'));
    step1_periph(8) = find(strcmp(countries_name, 'Slovenia'));
    step1_periph(9) = find(strcmp(countries_name, 'Slovakia'));
    step1_periph(10) = find(strcmp(countries_name, 'Spain'));
    % add also the ones that were excluded from the construction of the instrument for data availability, since they might have data on trade balance
    step1_periph(11) = find(strcmp(countries_name, 'Cyprus'));
    step1_periph(12) = find(strcmp(countries_name, 'Estonia'));
    step1_periph(13) = find(strcmp(countries_name, 'Lithuania'));
    
    classif_number = 2;
    countries_classif(step1_core,classif_number)   = 1;
    countries_classif(step1_periph,classif_number) = -1;
    countries_classif_summary = [countries_classif_summary; cellstr(char('Core (1) or periphery (-1) country within the EU from instrument composition, plus outliers'))];
    
    
    % %%% 3) size of country, according to GDP  
    step_weigths_countries_reordered2  = NaN*ones(size(countries_name,1),1);
    for i = 1:size(countries_name,1)
        try
            step_weigths_countries_reordered2(i) = step_weigths_countries(find(strcmp(step_weigths_countriesnames, countries_name(i))));
        catch
        end
    end
    
    classif_number = 3;
    countries_classif(:,classif_number) = step_weigths_countries_reordered2
    countries_classif_summary = [countries_classif_summary; cellstr(char('GDP weigth within EA'))];

    
    
    %% Compute Average trade balance 
    
    % select the list of variables used in Figure 7
    step1 = NaN*ones(18,1);
    step1(1) = find(strcmp(fullnames_data, 'AUT trade within EA19 in %'));
    step1(2) = find(strcmp(fullnames_data, 'BEL trade within EA19 in %'));
    step1(3) = find(strcmp(fullnames_data, 'CYP trade within EA19 in %'));
    step1(4) = find(strcmp(fullnames_data, 'EST trade within EA19 in %'));
    step1(5) = find(strcmp(fullnames_data, 'FIN trade within EA19 in %'));
    step1(6) = find(strcmp(fullnames_data, 'FRA trade within EA19 in %'));
    step1(7) = find(strcmp(fullnames_data, 'GER trade within EA19 in %'));
    step1(8) = find(strcmp(fullnames_data, 'GRE trade within EA19 in %'));
    step1(9) = find(strcmp(fullnames_data, 'IRE trade within EA19 in %'));
    step1(10) = find(strcmp(fullnames_data, 'ITA trade within EA19 in %'));
    step1(11) = find(strcmp(fullnames_data, 'LAT trade within EA19 in %'));
    step1(12) = find(strcmp(fullnames_data, 'LIT trade within EA19 in %'));
    step1(13) = find(strcmp(fullnames_data, 'LUX trade within EA19 in %'));
    step1(14) = find(strcmp(fullnames_data, 'MAL trade within EA19 in %'));
    step1(15) = find(strcmp(fullnames_data, 'PRT trade within EA19 in %'));
    step1(16) = find(strcmp(fullnames_data, 'SVN trade within EA19 in %'));
    step1(17) = find(strcmp(fullnames_data, 'SPA trade within EA19 in %'));
    step1(18) = find(strcmp(fullnames_data, 'NLD trade within EA19 in %'));
    
    step2 = region_data(step1);
    
    % %%% of net exporters and net importers, separately
    classif_number = 1;
    countries_classif_summary(classif_number);
    
    % Net exporters
    step3 = (countries_classif(:,classif_number) == 1) % net exporters
    step4 = countries_name(step3)
    step5 = NaN*ones(T_data,length(step4));
    for i = 1:length(step4)
        step4(i)
        step5(:,i) = data_monthly_all(:,step1(find(strcmp(step2, step4(i)))));
    end
    step6 = NaN*ones(T_data,1);
    % weighted by GDP
    q = find(strcmp(countries_classif_summary, 'GDP weigth within EA'));
    step7 = countries_classif(step3,q);
    for t = 1:T_data-2 % leave the last two observations NaN, since only Germany is available, hence the series drops just because the other series are not available, not because net export really decreases
        step6(t) =  step7(isnan(step5(t,:))==0)'*step5(t,isnan(step5(t,:))==0)'/sum(step7(isnan(step5(t,:))==0));
    end    

 
    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step6];
    fullnames_data       = [fullnames_data;        char('Average trade balance within net exporters, weighted by GDP')];
    betternames_data     = [betternames_data;      char('Average trade balance (net exporters)')];
    region_data          = [region_data;           char('EA')];
    transformIRFs_data   = [transformIRFs_data;    ones(1,1)];
    labelIRFs_data       = [labelIRFs_data;        char('% points')];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', 1, 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(T_data,1)];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         

    % Net importers
    step3 = (countries_classif(:,classif_number) == -1) % net exporters
    step4 = countries_name(step3)
    step5 = NaN*ones(T_data,length(step4));
    for i = 1:length(step4)
        step4(i);
        step5(:,i) = data_monthly_all(:,step1(find(strcmp(step2, step4(i)))));
    end
    step6 = NaN*ones(T_data,1);

    % weighted
    q = find(strcmp(countries_classif_summary, 'GDP weigth within EA'));
    step7 = countries_classif(step3,q);
    for t = 1:T_data-2 % leave the last two observations NaN, since only countries have available data, hence the series drops just because the other series are not available, not because net export really decreases
        step6(t) =  step7(isnan(step5(t,:))==0)'*step5(t,isnan(step5(t,:))==0)'/sum(step7(isnan(step5(t,:))==0));
    end  

    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step6];
    fullnames_data       = [fullnames_data;        char('Average trade balance within net importers, weighted by GDP')];
    betternames_data     = [betternames_data;      char('Average trade balance (net importers)')];
    region_data          = [region_data;           char('EA')];
    transformIRFs_data   = [transformIRFs_data;    ones(1,1)];
    labelIRFs_data       = [labelIRFs_data;        char('% points')];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', 1, 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(T_data,1)];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         
    
    % %%% of core and periphery countries, separately
    classif_number = 2;
    countries_classif_summary(classif_number);
    
    % Core countries
    step3 = (countries_classif(:,classif_number) == 1) % Core
    step4 = countries_name(step3)
    step5 = NaN*ones(T_data,length(step4));
    for i = 1:length(step4)
        step4(i);
        step5(:,i) = data_monthly_all(:,step1(find(strcmp(step2, step4(i)))));
    end
    step6 = NaN*ones(T_data,1);
    q = find(strcmp(countries_classif_summary, 'GDP weigth within EA'));
    step7 = countries_classif(step3,q);
    for t = 1:T_data-2 % leave the last two observations NaN, since only countries have available data, hence the series drops just because the other series are not available, not because net export really decreases
        step6(t) =  step7(isnan(step5(t,:))==0)'*step5(t,isnan(step5(t,:))==0)'/sum(step7(isnan(step5(t,:))==0));
    end  
   
    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step6];
    fullnames_data       = [fullnames_data;        char('Average trade balance within core countries, weighted by GDP')];
    betternames_data     = [betternames_data;      char('Average trade balance (weighted, core countries)')];
    region_data          = [region_data;           char('EA')];
    transformIRFs_data   = [transformIRFs_data;    ones(1,1)];
    labelIRFs_data       = [labelIRFs_data;        char('% points')];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', 1, 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(T_data,1)];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                         
    
    % Periphery countries
    step3 = (countries_classif(:,classif_number) == -1) % Periphery
    step4 = countries_name(step3)
    step5 = NaN*ones(T_data,length(step4));
    for i = 1:length(step4)
        step4(i);
        try
        step5(:,i) = data_monthly_all(:,step1(find(strcmp(step2, step4(i)))));
        catch 
        end % prevents from stopping at Slovakia, which has NaN data
    end
    step6 = NaN*ones(T_data,1);
    q = find(strcmp(countries_classif_summary, 'GDP weigth within EA'));
    step7 = countries_classif(step3,q);
    for t = 1:T_data-2 % leave the last two observations NaN, since only countries have available data, hence the series drops just because the other series are not available, not because net export really decreases
        step6(t) =  step7(isnan(step5(t,:))==0)'*step5(t,isnan(step5(t,:))==0)'/sum(step7(isnan(step5(t,:))==0));
    end  
    
    
    % Append to the existing data
    data_monthly_all     = [data_monthly_all,      step6];
    fullnames_data       = [fullnames_data;        char('Average trade balance within periphery countries, weighted by GDP')];
    betternames_data     = [betternames_data;      char('Average trade balance (weighted, periphery countries)')];
    region_data          = [region_data;           char('EA')];
    transformIRFs_data   = [transformIRFs_data;    ones(1,1)];
    labelIRFs_data       = [labelIRFs_data;        char('% points')];
    first_frequency_data = [first_frequency_data;  cellstr(repmat('monthly', 1, 1))];
    data_rswidentif      = [data_rswidentif,       NaN*ones(T_data,1)];

    k = size(data_monthly_all,2);

    assert(size(fullnames_data,1)       == k)
    assert(size(betternames_data,1)     == k)
    assert(size(region_data,1)          == k)
    assert(size(transformIRFs_data,1)   == k)
    assert(size(labelIRFs_data,1)       == k)
    assert(size(first_frequency_data,1) == k)
    assert(size(data_rswidentif,2)      == k)                                             
    
       
    %% SAVE THE MONTHLY DATA

    save('..\Temporary\Temporary_monthlydata', 'data_monthly_all', 'fullnames_data', 'betternames_data', 'region_data', 'transformIRFs_data', ...
                                    'labelIRFs_data', 'first_frequency_data', 'data_rswidentif', ...
                                    'logCPI_all_fullnames', 'logCPI_all_betternames', 'logCPI_all', 'logCPI_all_region', 'logCPI_all_transformIRFs', 'logCPI_all_labelIRFs', ...
                                    'countries_name', 'countries_n', 'countries_label', 'countries_classif', 'countries_classif_summary')

elseif do_full_computation == 0
     
    load('..\Temporary\Temporary_monthlydata')
    
end


%% IMPORT DATA FROM THE DAILY FREQUENCY USED IN THE CODE FOR THE PROXY, then CONVERT TO MONTHLY FREQUENCY 

% daily data are from 1.1.1999 to 30.12.2016, but only on traiding days
assert(year_shocks_daily(1)  == 1999)
assert(month_shocks_daily(1) == 1)
assert(day_shocks_daily(1)   == 1)

assert(year_shocks_daily(end)  == 2016)
assert(month_shocks_daily(end) == 12)
assert(day_shocks_daily(end)   == 30)

assert(size(alldailydata,1) == length(year_shocks_daily))

% convert to monthly frequency, controlling for the fact that only trading
% days are present 
assert(year_shocks_daily(1)  == year_data(1))
assert(month_shocks_daily(1) == month_data(1))

assert(year_shocks_daily(end)  == year_data(end))
assert(month_shocks_daily(end) == month_data(end))

step_data            = NaN*ones(T_data, size(alldailydata,2));
step_data_rswidentif = NaN*ones(T_data, size(alldailydata,2));
step_meantradingdays = NaN*ones(T_data, 1);
for yyy = year_data(1):year_data(end)
    for mmm = month_data(1):month_data(end)
        step_when = (year_shocks_daily==yyy).*(month_shocks_daily==mmm);
        step_ndays = sum(step_when);
        assert(step_ndays <= 31)
        
        step_when2 = find((year_data==yyy).*(month_data==mmm));
        step_data(step_when2,:)            = mean(alldailydata(step_when==1,:),1);       
        step_data_rswidentif(step_when2,:) = sum(alldailydata_diffaroundevents(step_when==1,:),1); 
        
        step_meantradingdays(step_when2)   = step_ndays;
    end
end

mean(step_meantradingdays)

% Append to the existing data
data_monthly_all     = [data_monthly_all,      step_data];
fullnames_data       = [fullnames_data;        alldailydata_fullnames];
betternames_data     = [betternames_data;      alldailydata_betternames];
region_data          = [region_data;           alldailydata_region];
transformIRFs_data   = [transformIRFs_data;    alldailydata_transformIRFs];
labelIRFs_data       = [labelIRFs_data;        alldailydata_labelIRFs];
first_frequency_data = [first_frequency_data;  cellstr(repmat('daily first', size(step_data,2), 1))];
data_rswidentif      = [data_rswidentif,       step_data_rswidentif];

k = size(data_monthly_all,2)

assert(size(fullnames_data,1)       == k)
assert(size(betternames_data,1)     == k)
assert(size(region_data,1)          == k)
assert(size(transformIRFs_data,1)   == k)
assert(size(labelIRFs_data,1)       == k)
assert(size(first_frequency_data,1) == k)
assert(size(data_rswidentif,2)      == k)                                         

clear alldailydata*
       

%% Final modifications

% drop Japan
step1 = find(strcmp(region_data, 'Japan'));
step2 = [1:1:size(data_monthly_all,2)];
step3 = setdiff(step2, step1); 

data_monthly_all     = data_monthly_all(:,step3);
fullnames_data       = fullnames_data(step3);
betternames_data     = betternames_data(step3);
region_data          = region_data(step3);
transformIRFs_data   = transformIRFs_data(step3);
labelIRFs_data       = labelIRFs_data(step3);
first_frequency_data = first_frequency_data(step3);
data_rswidentif      = data_rswidentif(:,step3); 

k = size(data_monthly_all,2)

assert(size(fullnames_data,1)       == k)
assert(size(betternames_data,1)     == k)
assert(size(region_data,1)          == k)
assert(size(transformIRFs_data,1)   == k)
assert(size(labelIRFs_data,1)       == k)
assert(size(first_frequency_data,1) == k)
assert(size(data_rswidentif,2)      == k)                                         


%% Reorganize 

[~, ordering] = sort(region_data);

data_monthly_all     = data_monthly_all(:,ordering);
fullnames_data       = fullnames_data(ordering);
betternames_data     = betternames_data(ordering);
region_data          = region_data(ordering);
transformIRFs_data   = transformIRFs_data(ordering);
labelIRFs_data       = labelIRFs_data(ordering);
first_frequency_data = first_frequency_data(ordering);
data_rswidentif      = data_rswidentif(:,ordering);  


%% Compute additional country classifications, needed for Figure 8

% compute difference in log of IP from beginning to end of the sample
choose_variab_step   = [1,27,53,216,242,273,307,333,359,390,415,455,480,506,531,557,587]; % IP

variab        = data_monthly_all(:,choose_variab_step);
variab_name   = fullnames_data(choose_variab_step);
variab_region = region_data(choose_variab_step);
variab_n      = length(variab_name);

% figure(1)
% for i = 1:variab_n
%   subplot(4,6,i)
%     plot(timeaxis_data, variab(:,i))
%     axis tight
%     set(gca,'box','off')
%     title(variab_name(i))
% end
% set(gcf,'Position',[0 0 1250*.8 1100*1.3]) 

step1 = isnan(variab)==0; % when available
step_start = NaN*ones(variab_n,1);
step_end   = NaN*ones(variab_n,1);
for i = 1:variab_n
    step2         = variab(step1(:,i),i);
    step_start(i) = step2(1);
    step_end(i)   = step2(end);
end

step_dif = 100*(step_end - step_start);

classif_number = 4;
for i = 1:variab_n
    j = find(strcmp(countries_name, variab_region(i))); 
    countries_classif(j,classif_number) = step_dif(i);
end
countries_classif_summary = [countries_classif_summary; cellstr(char('IP, variation from start to end of sample 100*(log diff)'))]; % USED IN FIGURE 8


% compute average trade balance 
choose_variab_step   = [17,43,69,215,232,261,290,323,349,378,406,431,454,471,496,547,575,603];
variab        = data_monthly_all(:,choose_variab_step);
variab_name   = fullnames_data(choose_variab_step);
variab_region = region_data(choose_variab_step);
variab_n      = length(variab_name)

% figure(4)
% for i = 1:variab_n
%   subplot(4,6,i)
%     plot(timeaxis_data, variab(:,i))
%     axis tight
%     set(gca,'box','off')
%     title(variab_name(i))
% end
% set(gcf,'Position',[0 0 1250*.8 1100*1.3]) 

step1 = isnan(variab)==0; % when available
step_mean = NaN*ones(variab_n,1);
for i = 1:variab_n
    step2         = variab(step1(:,i),i);
    step_mean(i)   = mean(step2);
end

classif_number = 5;
for i = 1:variab_n
    j = find(strcmp(countries_name, variab_region(i))); 
    countries_classif(j,classif_number) = step_mean(i);
end
countries_classif_summary = [countries_classif_summary; cellstr(char('Average trade balance (%)'))]; % USED IN FIGURE 8


%% Save dataset

data_allinfo = [fullnames_data, region_data, first_frequency_data, betternames_data, labelIRFs_data];

save('..\Temporary\Temporary_Data_full', 'year_data', 'month_data', 'timeaxis_data', ...
                                         'data_monthly_all', 'data_allinfo', 'fullnames_data', 'betternames_data', 'region_data', 'transformIRFs_data', 'labelIRFs_data', ...
                                         'first_frequency_data', 'data_rswidentif', ...
                                         'logCPI_all_fullnames', 'logCPI_all_betternames', 'logCPI_all', 'logCPI_all_region', 'logCPI_all_transformIRFs', 'logCPI_all_labelIRFs', ...
                                         'countries_name', 'countries_n', 'countries_label', 'countries_classif', 'countries_classif_summary')
   
save('..\Temporary\Temporary_Country_Classification', 'countries_name', 'countries_n', 'countries_label', 'countries_classif', 'countries_classif_summary')
   
                                     
                                     
'data saved'              

pause(1)
 
% %% Figures
% close all
% list_regions = unique(region_data)
% for r = 1:length(list_regions)
%     if strcmp(list_regions(r), 'EA') == 0      
%         figure(r)
% 
%         step1 = find(strcmp(region_data, list_regions(r)));
% 
%         for i=1:length(step1)
%             subplot(ceil(length(step1)/5), 5, i)
%             plot(timeaxis_data, data_monthly_all(:,step1(i))),
%             title(fullnames_data(step1(i)))
%             axis([timeaxis_data(1) timeaxis_data(end) -Inf Inf])
%             set(gca,'box','off')
%             grid
%         end
%         set(gcf,'Position',[0 0 2200*.7 1300*.7])
%         movegui('northwest')   
%     end
% end
% 
% % all EA
% step1 = find(strcmp(region_data, 'EA'));
% 
% figure(200)     
% for i=1:30
%     subplot(6, 5, i)
%     plot(timeaxis_data, data_monthly_all(:,step1(i))),
%     title(fullnames_data(step1(i)))
%     axis([timeaxis_data(1) timeaxis_data(end) -Inf Inf])
%     set(gca,'box','off')
%     grid
% end
% set(gcf,'Position',[0 0 2200*.7 1300*.7])
% movegui('northwest')  
% 
% figure(201)     
% for i=31:60
%     subplot(6, 5, i-30)
%     plot(timeaxis_data, data_monthly_all(:,step1(i))),
%     title(fullnames_data(step1(i)))
%     axis([timeaxis_data(1) timeaxis_data(end) -Inf Inf])
%     set(gca,'box','off')
%     grid
% end
% set(gcf,'Position',[0 0 2200*.7 1300*.7])
% movegui('northwest')
% 
% figure(202)     
% for i=61:length(step1)
%     subplot(6, 5, i-60)
%     plot(timeaxis_data, data_monthly_all(:,step1(i))),
%     title(fullnames_data(step1(i)))
%     axis([timeaxis_data(1) timeaxis_data(end) -Inf Inf])
%     set(gca,'box','off')
%     grid
% end
% set(gcf,'Position',[0 0 2200*.7 1300*.7])
% movegui('northwest')
% 
% assert( length(step1) <= 90)
% 
% 
% % all EA11
% step1 = find(strcmp(region_data, 'EA11'));
% 
% figure(300)     
% for i=1:length(step1)
%         subplot(ceil(length(step1)/5), 5, i)
%     plot(timeaxis_data, data_monthly_all(:,step1(i))),
%     title(fullnames_data(step1(i)))
%     axis([timeaxis_data(1) timeaxis_data(end) -Inf Inf])
%     set(gca,'box','off')
%     grid
% end
% set(gcf,'Position',[0 0 2200*.7 1300*.7])
% movegui('northwest')  
% 
% % all EA19
% step1 = find(strcmp(region_data, 'EA19'));
% 
% figure(300)     
% for i=1:length(step1)
%         subplot(ceil(length(step1)/5), 5, i)
%     plot(timeaxis_data, data_monthly_all(:,step1(i))),
%     title(fullnames_data(step1(i)))
%     axis([timeaxis_data(1) timeaxis_data(end) -Inf Inf])
%     set(gca,'box','off')
%     grid
% end
% set(gcf,'Position',[0 0 2200*.7 1300*.7])
% movegui('northwest')  
%                            
      