%==========================================================================

% Code for the replication of the paper "Unconventional Monetary Policy, 
% Fiscal Side Effects and Euro Area (Im)balances", Journal of the European
% Economic Association, by Michael Hachula, Michele Piffer and Malte Rieth

% Michele Piffer, m.b.piffer@gmail.com
% https://sites.google.com/site/michelepiffereconomics/
% October 2018, Queen Mary, University of London

%==========================================================================


close all

load('..\Temporary\Temporary_Data_full');


T_step = [1:1:T_irf];

Loops        = 500; 

grey  = [0.8,0.8,0.8]; 
grey2 = [0.6,0.6,0.6];
red   = [0.6,0.1,0.2];
blue  = [0.25,0.3,0.8];
red2  = [0.65,0.1,0.2];
blue2 = [0.3,0.6,0.9];


%% VARIABLES STUDIED 
assert( size(data_monthly_all,1) ==  length(year_data))
assert( size(data_monthly_all,1) ==  length(month_data))

k_base             = length(choose_base_variab);
choose_variab      = choose_base_variab;
position_indicator = 1; 

plot_x = 2;
plot_y = 4;


if add_variables == 0
    n_added_variab = 1; % value required only to start the loop
    
elseif add_variables == 1
 

n_added_variab                  = length(choose_added_variab);
IRFs_rswmethod_all_variab       = NaN*ones(k_base+1, T_irf,    n_added_variab);
IRFs_rswmethod_bands_all_variab = NaN*ones(k_base+1, T_irf, 2, n_added_variab);
IRFs_rswmethod_loop_all_variab  = NaN*ones(k_base+1, T_irf, Loops, n_added_variab);

table_FEVD_rswmethod_all_variab = NaN*ones(4, 1+k_base+1, n_added_variab);

names_IRFs_all_variab    = cell(k_base+1, n_added_variab);
labelIRFs_all_variab     = cell(k_base+1, n_added_variab);
transformIRFs_all_variab = NaN*ones(k_base+1, n_added_variab);
region_all_variab        = cell(k_base+1, n_added_variab);

end

    
for add = 1:n_added_variab

    
disp('========================================================================')
still_to_go = n_added_variab-add +1

if add_variables == 0
    choose_variab = choose_base_variab;
elseif add_variables == 1
    choose_variab = [choose_base_variab, choose_added_variab(add)];
end


Y               = data_monthly_all(:,choose_variab);
names           = fullnames_data(choose_variab);
names_IRFs      = betternames_data(choose_variab);
transformIRFs   = transformIRFs_data(choose_variab);
labelIRFs       = labelIRFs_data(choose_variab);
frequency       = first_frequency_data(choose_variab);
rswidentif      = data_rswidentif(:,choose_variab);
region          = region_data(choose_variab);

disp('-->> Variables in the VAR: ' );
names


if add_variables == 0
    names_IRFs_base_variab    = names_IRFs;
    labelIRFs_base_variab     = labelIRFs;
    transformIRFs_base_variab = transformIRFs;
    region_base_variab        = region;
    
elseif add_variables == 1
    names_IRFs_all_variab(:,add)    = names_IRFs; 
    labelIRFs_all_variab(:,add)     = labelIRFs;
    transformIRFs_all_variab(:,add) = transformIRFs;
    region_all_variab(:,add)        = region;
    
end


% reduce to period for which all measures are available
cond  = isnan(Y);
cond2 = sum(cond,2) == 0;

Y = Y(cond2,:);
k = size(Y,2);

data_are_available = size(Y,1)>1;
if data_are_available == 1

    
year_available     = year_data(cond2);
month_available    = month_data(cond2);
timeaxis_available = timeaxis_data(cond2);
rswidentif_bis     = rswidentif(cond2,:); 


% Reduced form model estimated in the intersection between the period
% between "from" and "until", and the period for which the data are
% available.
from  = 1999; 
until = 2017; 

cond  = (timeaxis_available >= from).*(timeaxis_available <= until);
Y     = Y(cond==1,:);
timeaxis_available = timeaxis_available(cond==1);
year_available     = year_available(cond==1);
month_available    = month_available(cond==1);
rswidentif_bis     = rswidentif_bis(cond==1,:);


disp(['-->> Reduced form model estimated with data in the period :    ', num2str(year_available(1))   'M' num2str(month_available(1)) ...
                                ' until ', num2str(year_available(end))   'M' num2str(month_available(end))] );                   
                            
% ensure Y enters horizontally
Y = Y';
T = size(Y,2);
assert(  T > k)
assert( length(timeaxis_available) == T)


% figure(1)
% for i = 1:k
%         subplot(ceil(k/2),2,i)
%         plot(timeaxis_available, Y(i,:), 'k', 'Linewidth', 2), hold on;
%         axis tight
% %         title(names(i));
%         title(names_IRFs(i));
%         set(gca,'box','off');
%         grid
% end
% set(gcf, 'PaperPositionMode', 'auto');
% set(gcf,'Position',[0 0 1050*.7 700*.7])
% movegui('northwest')


%% ESTIMATION               
constantD   = 1;
trendD      = 0;
trendBreaks = [];
seasonD     = 0;
moreBreaks  = [];
p           = 5; 
                            
[Ahat, Resid, Sigmahat, Ahat_determ, X_determ, T_used, df_lost, BIC, AIC] = ...
               zFC_VAR_Estimation3(Y,p,constantD,trendD,trendBreaks,seasonD,moreBreaks);
          

year_used     = year_available(p+1:end);
month_used    = month_available(p+1:end);           
timeaxis_used = timeaxis_available(p+1:end);
rswidentif_bis_used          = rswidentif_bis(p+1:end,:);
assert(length(timeaxis_used) == size(Resid,2))


%% Identification via Instruments
load('..\Temporary\Temporary_ConstructedProxy_withdailybetas')
            
Instruments_step                 = shocks_monthly;

assert( size(Instruments_step,1) == length(timeaxis_shocks_monthly) )
assert( size(Instruments_step,1) == length(year_shocks_monthly) )
assert( size(Instruments_step,1) == length(month_shocks_monthly) )

assert( size(rswidentif,1) == length(Instruments_step) )

% Select only period for which the instrument is available
step1 = isnan(Instruments_step);
step2 = step1 == 0;
Instruments_step        = Instruments_step(step2, :);
timeaxis_shocks_monthly = timeaxis_shocks_monthly(step2);
year_shocks_monthly     = year_shocks_monthly(step2);
month_shocks_monthly    = month_shocks_monthly(step2);
rswidentif              = rswidentif(step2, :);

disp(['-->> Instrument available for :    ', num2str(year_shocks_monthly(1))   'M' num2str(month_shocks_monthly(1)) ...
                                  ' until ', num2str(year_shocks_monthly(end)) 'M' num2str(month_shocks_monthly(end))] );
   

% Select the subperiod covered fully by both residuals and instruments, then rearrange
from2          = max(timeaxis_used(1),  timeaxis_shocks_monthly(1));
until2         = min(timeaxis_used(end),timeaxis_shocks_monthly(end));
timeaxis_used2 = [from2:1/12:until2];             

data_are_available2 = length(timeaxis_used2)>10;

if data_are_available2 == 1 % identify the model only if there are enough observations in the data that overlap with the observations in the instrument 
    
disp(['-->> Period effectively used in the identification :    ', num2str(year_used(timeaxis_used==from2))   'M' num2str(month_used(timeaxis_used==from2)) ...
                                                       ' until ', num2str(year_used(timeaxis_used==until2))  'M' num2str(month_used(timeaxis_used==until2))] );
                        
                            
% Take only the instrument in this subperiod
cond1            = timeaxis_shocks_monthly >= from2 & timeaxis_shocks_monthly <= until2;
Instruments_used = Instruments_step(cond1,:);
rswidentif_used  = rswidentif(cond1,:);
assert(length(timeaxis_used2) == length(Instruments_used))
assert(length(timeaxis_used2) == size(rswidentif_used,1))

% Take only the residuals in this subperiod
cond2      = timeaxis_used >= from2 & timeaxis_used <= until2;
Resid_used = Resid(:,cond2);
assert(length(timeaxis_used2) == size(Resid_used,2))   


%% Identification of the model

[imp_vect_relat_step, imp_vect_absol_step, imp_vect_inconsist_step, ...
             F_stat_test1_step, p_values_test1_step, signif_test1_step, Rsquared_test1_step, Betas_test1_step, ...
             ~, ~, ~, ~, ...
             correl_instrument_shock, a_vect, estim_shocks, ~, ~] = zFC_IdentifExtInstruments7(Resid_used', Instruments_used, position_indicator, Sigmahat);
         
use_daily = find(strcmp(frequency, 'daily first'));

% If do it as in RSW
imp_vect_inconsist_rswmethod  = imp_vect_inconsist_step; 
F_stat_test1_rswmethod        = F_stat_test1_step;
for j = 1:length(use_daily)
    step_yyy      = rswidentif_used(:,use_daily(j));
    step_xxx      = [Instruments_used, ones(size(Instruments_used,1),1)];
    step_beta_hat = (step_xxx'*step_xxx)^(-1)*step_xxx'*step_yyy;
    step_rsw      = step_beta_hat(1); 

    imp_vect_inconsist_rswmethod(use_daily(j)) = step_rsw;

    [F_test, ~, ~]  = zFC_Ftest_Autocorr_Homosk(step_yyy,step_xxx,ones(size(Instruments_used,1),1));
    F_stat_test1_rswmethod(use_daily(j)) = F_test(1);
end


% If do it as in RSW
imp_vect_absol_rswmethod = zFC_inconst_to_absol_imp_vect(imp_vect_inconsist_rswmethod, position_indicator, Sigmahat);


% Correlations between shock and instrument
phi_rswmethod = imp_vect_inconsist_rswmethod(1)./imp_vect_absol_rswmethod(1) ;


%% Compute correpsonding IRFs
shocked_variab        = 1; % don't change, even if differs from position of fed funds

% Choose which type of shock to give
% shock_in_IRF = 'shock such that i decreases by 25 bp';  shock_in_bp = -0.25; 
shock_in_IRF = 'one standard deviation shock'; % Baseline


% If do it as in RSW
P                         =  [imp_vect_absol_rswmethod, zeros(k,k-1)];
if strcmp(shock_in_IRF, 'shock such that i decreases by 25 bp') == 1
    shock_given_rswmethod = shock_in_bp/abs(P(position_indicator,shocked_variab));
elseif strcmp(shock_in_IRF, 'one standard deviation shock') == 1
    shock_given_rswmethod = -sign(P(position_indicator, shocked_variab))*1;    
end    
IRFs_rswmethod            = zFC_IRFs(Ahat, P, T_irf, shocked_variab, shock_given_rswmethod);


if add_variables == 0   
     IRFs_rswmethod_base_variab = IRFs_rswmethod;
    
elseif add_variables == 1   
     IRFs_rswmethod_all_variab(:,:,add) = IRFs_rswmethod;
     
end


%% Variance decomposition
horizons = [3,12,24,36]';
H        = length(horizons);
Var_struct_shocks       = eye(k); 
[MovAverage_reduced, ~] = zFC_RewriteVAR(Ahat, randn(k,k), max(horizons));

% If do it as in RSW
impvec                           = imp_vect_absol_rswmethod;  
B_extin2                         = [impvec, randn(k,k-1)];
[~, MovAverage_structural_extin] = zFC_RewriteVAR(Ahat, B_extin2, max(horizons));
Vdecomp  = NaN*ones(H,k);
for h = 1:H
    hor = horizons(h);    
    for variab = 1:k
        shock = 1;
        Vdecomp(h,variab) = zFC_VarianceDecomposition_partially(shock, variab, hor, Sigmahat, MovAverage_reduced, Var_struct_shocks, MovAverage_structural_extin);   
    end
end
table_FEVD_rswmethod = [horizons, round(Vdecomp)];


%% Bootstrap on the reduced form model 
Yinit           = Y(:,1:p);
Ahat_loop       = NaN*ones(k,k*p,Loops);
Resid_used_loop = NaN*ones(k,length(Resid_used),Loops);
Sigmahat_loop   = NaN*ones(k,k,Loops);
Instruments_used_loop = NaN*ones(size(Instruments_used,1),size(Instruments_used,2),Loops);
rswidentif_used_loop  = NaN*ones(length(Resid_used),k,Loops);

for l = 1:Loops
    if (Loops-l/100) == floor(Loops-l/100)
        disp([' Missing loops within bootstrap: ', num2str(Loops-l)] );        
    end
    
    %%%% WILD BOOTSTRAP
    % Generate a vector that flips signs randomly
    step = randn(T_used,1);
    change_sign = -1*ones(T_used,1);
    change_sign(step > 0) = 1;
    
    % Generate pseudo data
    Resid_pseudo = Resid*diag(change_sign);
    
    Y_pseudo = zFC_GenerateVARData(Yinit, Ahat, Resid_pseudo, Ahat_determ, X_determ);

    % Estimate the VAR on the pseudo data
    [Ahat_loop(:,:,l), Resid_step, Sigmahat_loop(:,:,l), ~, ~, ~, ~] = ...
                    zFC_VAR_Estimation3(Y_pseudo,p,constantD,trendD,trendBreaks,seasonD,moreBreaks);
               
    % Store residuals for the subpart that overlaps with the shocks used
    Resid_used_loop(:,:,l) = Resid_step(:,cond2);

    % Flip sign of the instruments using the same order in the bootstrapped residuals, consider only the part that overlaps with the residuals
    Instruments_used_loop(:,:,l) = diag(change_sign(cond2))*Instruments_used;        
    rswidentif_used_loop(:,:,l)  = diag(change_sign(cond2))*rswidentif_used;
end

% %%%% BOOTSTRAP-AFTER-BOOTSTRAP BY KILIAN
[Ahat_loop, ~] = zFC_VARbootstrap_Kilian2(Y,p,constantD,trendD,trendBreaks,seasonD,moreBreaks,k,Loops); 
    

%% IRFs, error bands  
IRFs_rswmethod_loop = NaN*ones(k,T_irf,Loops);

for l = 1:Loops  
    [~, imp_vect_absol_step_loop, imp_vect_inconsist_step_loop, ...
         ~, ~, ~, ~, ...
         ~, ~, ~, ~, ...
         ~, ~, ~, ~, ~] = zFC_IdentifExtInstruments7( ...
                         Resid_used_loop(:,:,l)', Instruments_used_loop(:,l), position_indicator, Sigmahat_loop(:,:,l));
                             

    % IRFs when identifying using method by RSW
    imp_vect_inconsist_rswmethod_loop  = imp_vect_inconsist_step_loop;

    step_yyy      = rswidentif_used_loop(:,use_daily,l);
    step_xxx      = [Instruments_used_loop(:,l), ones(size(Instruments_used,1),1)];
    step_beta_hat = (step_xxx'*step_xxx)^(-1)*step_xxx'*step_yyy;
    step_rsw      = step_beta_hat(1,:)'; 
    imp_vect_inconsist_rswmethod_loop(use_daily) = step_rsw;
    
    imp_vect_absol_rswmethod_loop = zFC_inconst_to_absol_imp_vect(imp_vect_inconsist_rswmethod_loop, position_indicator, Sigmahat_loop(:,:,l));   
    P_loop                        = [imp_vect_absol_rswmethod_loop, zeros(k,k-1)];
    if strcmp(shock_in_IRF, 'shock such that i decreases by 25 bp') == 1
        shock_given_rswmethod_loop = shock_given_rswmethod;
    elseif strcmp(shock_in_IRF, 'one standard deviation shock') == 1
        shock_given_rswmethod_loop = shock_given_rswmethod;
    end
    IRFs_rswmethod_loop(:,:,l) = zFC_IRFs(Ahat_loop(:,:,l), P_loop, T_irf, shocked_variab, shock_given_rswmethod_loop);
    
end

% Compute error bands
IRFs_rswmethod_bands = NaN*ones(k,T_irf,2);
interval             = 10;
for ttt = 1:T_irf 
    for kkk = 1:k  
        IRFs_rswmethod_bands(kkk,ttt,1)  =  prctile(IRFs_rswmethod_loop(kkk,ttt,:),interval/2);
        IRFs_rswmethod_bands(kkk,ttt,2)  =  prctile(IRFs_rswmethod_loop(kkk,ttt,:),100-interval/2);  
    end
end


elseif data_are_available2 == 0

IRFs_rswmethod       = NaN*ones(k,T_irf);     
IRFs_rswmethod_bands = NaN*ones(k,T_irf,2);
IRFs_rswmethod_loop  = NaN*ones(k,T_irf,Loops);
table_FEVD_rswmethod = NaN*ones(4,k+1);

end

elseif data_are_available == 0
    
IRFs_rswmethod       = NaN*ones(k,T_irf);
IRFs_rswmethod_bands = NaN*ones(k,T_irf,2);
IRFs_rswmethod_loop  = NaN*ones(k,T_irf,Loops);
table_FEVD_rswmethod = NaN*ones(4,k+1);
   
end



if add_variables == 0
     IRFs_rswmethod_bands_base_variab = IRFs_rswmethod_bands;
     IRFs_rswmethod_loop_base_variab  = IRFs_rswmethod_loop;
     table_FEVD_rswmethod_base_variab = table_FEVD_rswmethod;

     save('..\Temporary\Temporary_IRFs_base_variab', 'IRFs_rswmethod_base_variab', ...
                                                     'IRFs_rswmethod_bands_base_variab', ...
                                                     'IRFs_rswmethod_loop_base_variab', ...
                                                     'transformIRFs_base_variab', 'names_IRFs_base_variab', 'labelIRFs_base_variab', 'region_base_variab', ...
                                                     'table_FEVD_rswmethod_base_variab', ...
                                                     'k_base', 'shock_in_IRF')

     '>>> IRFs from Baseline VAR saved <<<'   
    
elseif add_variables == 1
     IRFs_rswmethod_bands_all_variab(:,:,:,add) = IRFs_rswmethod_bands;
     IRFs_rswmethod_loop_all_variab(:,:,:,add)  = IRFs_rswmethod_loop;
     table_FEVD_rswmethod_all_variab(:,:,add)   = table_FEVD_rswmethod;
     
     if add == n_added_variab
        save('..\Temporary\Temporary_IRFs_all_variab', 'IRFs_rswmethod_all_variab', ...
                                                       'IRFs_rswmethod_bands_all_variab', ...
                                                       'IRFs_rswmethod_loop_all_variab', ...
                                                       'transformIRFs_all_variab', 'names_IRFs_all_variab', 'labelIRFs_all_variab', 'region_all_variab', ...
                                                       'table_FEVD_rswmethod_all_variab', ...
                                                       'k_base', 'n_added_variab', 'shock_in_IRF') 

                                        
     '>>> IRFs from all Marginal VARs saved <<<'   
     pause(1)

     end     
end

end



if add_variables == 1 
close all
    
load('..\Temporary\Temporary_IRFs_base_variab')
load('..\Temporary\Temporary_IRFs_all_variab')


%% COMPUTE PEAKs for the marginal variables

if Figure_numb == 7
    T_step_useforpeaks = [1:1:T_irf];
else
    T_step_useforpeaks = T_step;
end

step1        = squeeze(IRFs_rswmethod_all_variab(k_base+1,T_step_useforpeaks,:))' ;
step1_bandsL = squeeze(IRFs_rswmethod_bands_all_variab(k_base+1,T_step_useforpeaks,1,:))' ;
step1_bandsH = squeeze(IRFs_rswmethod_bands_all_variab(k_base+1,T_step_useforpeaks,2,:))' ;

step2 = abs(step1);
step3 = max(step2')';
step4 = [];
for i = 1:n_added_variab
   step4 = [step4; step2(i,:)==step3(i)]; 
end
[peak_effects_rswmethod_when, ~] = find(step4');
peak_effects_rswmethod_when      = T_step_useforpeaks(peak_effects_rswmethod_when);
step5 = step1.*step4 ;
peak_effects_rswmethod = transformIRFs_all_variab(k_base+1,:)'.*sum(step5,2) ;
step6 = step1_bandsL.*step4 ;
step7 = step1_bandsH.*step4 ;
peak_effects_rswmethod_bounds = [transformIRFs_all_variab(k_base+1,:)'.*sum(step6,2), transformIRFs_all_variab(k_base+1,:)'.*sum(step7,2)];



%% FEVDs 

disp(['FEVDs'])
FEVD = [table_FEVD_rswmethod_base_variab(:,1), NaN*ones(H,1), table_FEVD_rswmethod_base_variab(:,2:end), NaN*ones(H,1), squeeze(table_FEVD_rswmethod_all_variab(:,end,:))]


%% IRFs constructed on IRFs of other variables


n_new_variab = 0;

if need_5x5 == 1 %%% If do computation of 5x5 forward inflation swap
    n_new_variab = 1;

    which_step3 = find(strcmp(names_IRFs_all_variab(k_base+1, :), 'Ten-year inflation swap rate')); 
    names_IRFs_all_variab(k_base+1, which_step3)
    which_step4 = find(strcmp(names_IRFs_all_variab(k_base+1, :), 'Five-year inflation swap rate')); 
    names_IRFs_all_variab(k_base+1, which_step4)

    IRFs_rswmethod_new_variab = ((1+IRFs_rswmethod_all_variab(k_base+1,:,which_step3)).^10./(1+IRFs_rswmethod_all_variab(k_base+1,:,which_step4)).^5).^(0.2)-1 ;    
    IRFs_rswmethod_loop_new_variab = NaN*ones(n_new_variab, T_irf, Loops);
    for l = 1:Loops
        IRFs_rswmethod_loop_new_variab(1, :, l) = ((1+IRFs_rswmethod_loop_all_variab(k_base+1,:,l,which_step3)).^10./(1+IRFs_rswmethod_loop_all_variab(k_base+1,:,l,which_step4)).^5).^(0.2)-1 ;
    end

    transformIRFs_new_variab = [NaN*ones(k_base,1); transformIRFs_all_variab(k_base+1, which_step3)];
    names_IRFs_new_variab    = [names_IRFs_all_variab(1:k_base,which_step3); '5x5 forward inflation swap'];
    labelIRFs_new_variab     = [labelIRFs_all_variab(1:k_base,which_step3); labelIRFs_all_variab(k_base+1,which_step3)];
    region_new_variab        = [region_all_variab(1:k_base,which_step3); region_all_variab(k_base+1,which_step3)];

    IRFs_rswmethod_bands_new_variab = NaN*ones(n_new_variab,T_irf,2);

    for ttt = 1:T_irf 
        for add = 1:n_new_variab
            IRFs_rswmethod_bands_new_variab(add,ttt,1)  =  prctile(IRFs_rswmethod_loop_new_variab(add,ttt,:),interval/2);
            IRFs_rswmethod_bands_new_variab(add,ttt,2)  =  prctile(IRFs_rswmethod_loop_new_variab(add,ttt,:),100-interval/2);  
        end
    end   
    
else
end

                                      
%% SAVE ALL STATISTICS COMPUTED

if which_phase_considered == 1
    step_name = strcat('CMP'); 
elseif which_phase_considered == 2
    step_name = strcat('UMP1'); 
elseif which_phase_considered == 3
    step_name = strcat('UMP2'); 
end


load('..\Temporary\Temporary_IRFs_base_variab')

save(['..\Temporary\Temporary_IRFs_base_variab_', step_name], ...
                                          'IRFs_rswmethod_base_variab', ...
                                          'IRFs_rswmethod_bands_base_variab', ...
                                          'transformIRFs_base_variab', 'names_IRFs_base_variab', 'labelIRFs_base_variab', 'region_base_variab', ...
                                          'table_FEVD_rswmethod_base_variab', ...
                                          'k_base', 'shock_in_IRF') 
                                      
                                      
load('..\Temporary\Temporary_IRFs_all_variab')

if n_new_variab > 0   
% Append to existing stored statistics

    if need_5x5 == 1
    %%% If add 5x5 and drop last two

        which_position = 3;

        IRFs_rswmethod_all_variab = cat(3, IRFs_rswmethod_all_variab(:,:,1:which_position-1), ...
                                           [NaN*ones(k-1,T_irf); IRFs_rswmethod_new_variab], ...
                                           IRFs_rswmethod_all_variab(:,:,which_position:end));

        IRFs_rswmethod_bands_all_variab = cat(4, IRFs_rswmethod_bands_all_variab(:,:,:,1:which_position-1), ...
                                                 [NaN*ones(k-1,T_irf,2); IRFs_rswmethod_bands_new_variab], ...
                                                 IRFs_rswmethod_bands_all_variab(:,:,:,which_position:end));


                                             
        transformIRFs_all_variab = cat(2, transformIRFs_all_variab(:,1:which_position-1), transformIRFs_new_variab, transformIRFs_all_variab(:,which_position:end));
        names_IRFs_all_variab    = cat(2, names_IRFs_all_variab(:,1:which_position-1), names_IRFs_new_variab, names_IRFs_all_variab(:,which_position:end));
        labelIRFs_all_variab     = cat(2, labelIRFs_all_variab(:,1:which_position-1), labelIRFs_new_variab, labelIRFs_all_variab(:,which_position:end));
        region_all_variab        = cat(2, region_all_variab(:,1:which_position-1), region_new_variab, region_all_variab(:,which_position:end));

        n_added_variab = n_added_variab + n_new_variab;

        % drop last two variables if added just to compute other variables (5x5)
        keep_variab = [1:1:10];
        IRFs_rswmethod_all_variab = IRFs_rswmethod_all_variab(:,:,keep_variab);
        IRFs_rswmethod_bands_all_variab = IRFs_rswmethod_bands_all_variab(:,:,:,keep_variab);

        transformIRFs_all_variab = transformIRFs_all_variab(:,keep_variab);
        names_IRFs_all_variab    = names_IRFs_all_variab(:,keep_variab);
        labelIRFs_all_variab     = labelIRFs_all_variab(:,keep_variab);
        region_all_variab        = region_all_variab(:,keep_variab);

        n_added_variab = length(keep_variab);
        

    else
    end
  
end

                                     
save(['..\Temporary\Temporary_IRFs_all_variab_', step_name], ...
                                          'IRFs_rswmethod_all_variab', ...
                                          'IRFs_rswmethod_bands_all_variab', ...
                                          'transformIRFs_all_variab', 'names_IRFs_all_variab', 'labelIRFs_all_variab', 'region_all_variab', ...
                                          'table_FEVD_rswmethod_all_variab', ...
                                          'peak_effects_rswmethod', ...
                                          'peak_effects_rswmethod_when', ...
                                          'peak_effects_rswmethod_bounds', ...                                          
                                          'k_base', 'n_added_variab', 'shock_in_IRF', ...
                                          'Figure_numb')                                       
                                      
'>>> IRFs for comparison saved <<<'   

       
  
end
