%==========================================================================

% Code for the replication of the paper "Unconventional Monetary Policy, 
% Fiscal Side Effects and Euro Area (Im)balances", Journal of the European
% Economic Association, by Michael Hachula, Michele Piffer and Malte Rieth

% Michele Piffer, m.b.piffer@gmail.com
% https://sites.google.com/site/michelepiffereconomics/
% October 2018, Queen Mary, University of London

%==========================================================================


clc
clear
close all

grey  = [0.8,0.8,0.8]; 
grey2 = [0.6,0.6,0.6];
red   = [0.6,0.1,0.2];
blue  = [0.25,0.3,0.8];
red2  = [0.65,0.1,0.2];
blue2 = [0.3,0.6,0.9];


%% SELECT IF THE FIGURE SHOWS CONVENTIONAL, UMP, UMP1 OR UMP2
what_to_show      = [0,1,1]; % For Figures 1-8
% what_to_show      = [1,1,1]; % For Figure 9
% what_to_show      = [1,1,0]; % For Figure 10-11

name_regimesshown = char('CMP', ...
                         'UMP1', ...
                         'UMP2');
                     
legend_regimesshown = char('Conventional', ...
                           'Phase 1', ...
                           'Phase 2');
                       

name_regimesshown   = cellstr(name_regimesshown);
legend_regimesshown = cellstr(legend_regimesshown);


%% Load Statistics

% % % Case 1
if what_to_show(1) == 1

    load(['..\Temporary\Temporary_IRFs_base_variab_', char(name_regimesshown(1))])    
    Case1_IRFs_rswmethod_base_variab = IRFs_rswmethod_base_variab;
    Case1_IRFs_rswmethod_bands_base_variab = IRFs_rswmethod_bands_base_variab;
    Case1_transformIRFs_base_variab        = transformIRFs_base_variab;
    Case1_names_IRFs_base_variab           = names_IRFs_base_variab;
    Case1_labelIRFs_base_variab            = labelIRFs_base_variab;
    Case1_region_base_variab               = region_base_variab;
    Case1_k_base                           = k_base;

    load(['..\Temporary\Temporary_IRFs_all_variab_', char(name_regimesshown(1))])
    Case1_IRFs_rswmethod_all_variab = IRFs_rswmethod_all_variab;
    Case1_IRFs_rswmethod_bands_all_variab = IRFs_rswmethod_bands_all_variab; 
    Case1_peak_effects        = peak_effects_rswmethod;
    Case1_peak_effects_when   = peak_effects_rswmethod_when;
    Case1_peak_effects_bounds = peak_effects_rswmethod_bounds;       
    
    Case1_transformIRFs_all_variab = transformIRFs_all_variab;
    Case1_names_IRFs_all_variab = names_IRFs_all_variab;
    Case1_labelIRFs_all_variab = labelIRFs_all_variab;
    Case1_region_all_variab = region_all_variab;
    Case1_n_added_variab = n_added_variab;
                                      
end

% % % Case 2
if what_to_show(2) == 1

    load(['..\Temporary\Temporary_IRFs_base_variab_', char(name_regimesshown(2))])
    Case2_IRFs_rswmethod_base_variab = IRFs_rswmethod_base_variab;
    Case2_IRFs_rswmethod_bands_base_variab = IRFs_rswmethod_bands_base_variab;
    Case2_transformIRFs_base_variab        = transformIRFs_base_variab;
    Case2_names_IRFs_base_variab           = names_IRFs_base_variab;
    Case2_labelIRFs_base_variab            = labelIRFs_base_variab;
    Case2_region_base_variab               = region_base_variab;
    Case2_k_base                           = k_base;

    load(['..\Temporary\Temporary_IRFs_all_variab_', char(name_regimesshown(2))])
    Case2_IRFs_rswmethod_all_variab = IRFs_rswmethod_all_variab;
    Case2_IRFs_rswmethod_bands_all_variab = IRFs_rswmethod_bands_all_variab;
    Case2_peak_effects        = peak_effects_rswmethod;
    Case2_peak_effects_when   = peak_effects_rswmethod_when;
    Case2_peak_effects_bounds = peak_effects_rswmethod_bounds;                
  
    Case2_transformIRFs_all_variab = transformIRFs_all_variab;
    Case2_names_IRFs_all_variab = names_IRFs_all_variab;
    Case2_labelIRFs_all_variab = labelIRFs_all_variab;
    Case2_region_all_variab = region_all_variab;
    Case2_n_added_variab = n_added_variab;

end

% % % Case 3
if what_to_show(3) == 1

    load(['..\Temporary\Temporary_IRFs_base_variab_', char(name_regimesshown(3))])
    Case3_IRFs_rswmethod_base_variab = IRFs_rswmethod_base_variab;
    Case3_IRFs_rswmethod_bands_base_variab = IRFs_rswmethod_bands_base_variab;
    Case3_transformIRFs_base_variab        = transformIRFs_base_variab;
    Case3_names_IRFs_base_variab           = names_IRFs_base_variab;
    Case3_labelIRFs_base_variab            = labelIRFs_base_variab;
    Case3_region_base_variab               = region_base_variab;
    Case3_k_base                           = k_base;

    load(['..\Temporary\Temporary_IRFs_all_variab_', char(name_regimesshown(3))])
    Case3_IRFs_rswmethod_all_variab = IRFs_rswmethod_all_variab;
    Case3_IRFs_rswmethod_bands_all_variab = IRFs_rswmethod_bands_all_variab;
    Case3_peak_effects        = peak_effects_rswmethod;
    Case3_peak_effects_when   = peak_effects_rswmethod_when;
    Case3_peak_effects_bounds = peak_effects_rswmethod_bounds;            
  
    Case3_transformIRFs_all_variab = transformIRFs_all_variab;
    Case3_names_IRFs_all_variab = names_IRFs_all_variab;
    Case3_labelIRFs_all_variab = labelIRFs_all_variab;
    Case3_region_all_variab = region_all_variab;
    Case3_n_added_variab = n_added_variab;
    
end


if what_to_show(1) == 1
    T_irf  = size(Case1_IRFs_rswmethod_base_variab,2);
    k_base = Case1_k_base;
    n_added_variab = Case1_n_added_variab;   
    names_IRFs_base_variab = Case1_names_IRFs_base_variab;
    names_IRFs_all_variab  = Case1_names_IRFs_all_variab;
    labelIRFs_base_variab  = Case1_labelIRFs_base_variab;
    labelIRFs_all_variab   = Case1_labelIRFs_all_variab;
    region_all_variab      = Case1_region_all_variab;
elseif what_to_show(2) == 1
    T_irf  = size(Case2_IRFs_rswmethod_base_variab,2);
    k_base = Case2_k_base;
    n_added_variab = Case2_n_added_variab;
    names_IRFs_base_variab = Case2_names_IRFs_base_variab;
    names_IRFs_all_variab  = Case2_names_IRFs_all_variab;
    labelIRFs_base_variab  = Case2_labelIRFs_base_variab;
    labelIRFs_all_variab   = Case2_labelIRFs_all_variab;
    region_all_variab = Case2_region_all_variab;    
elseif what_to_show(3) == 1
    T_irf                 = size(Case3_IRFs_rswmethod_base_variab,2);
    k_base                = Case3_k_base;
    n_added_variab        = Case3_n_added_variab;    
    names_IRFs_base_variab = Case3_names_IRFs_base_variab;
    names_IRFs_all_variab  = Case3_names_IRFs_all_variab;  
    labelIRFs_base_variab  = Case3_labelIRFs_base_variab;
    labelIRFs_all_variab   = Case3_labelIRFs_all_variab;
    region_all_variab      = Case3_region_all_variab;
end
T_step = [1:1:T_irf];

    
close all

% If compare to conventional
if what_to_show(1) == 1
    names_IRFs_base_variab = cellstr(names_IRFs_base_variab);
    names_IRFs_base_variab(1) = {'Policy indicator'};
end

                
%% IRF figure for only the base variables
legendwhat = [];
legendinfo = [];

figure(200)
for i = 1:k_base
   subplot(ceil(k_base/2),2,i)
   
plot(T_step, zeros(T_irf,1), 'k'), hold on
   
   
% % % Case 1
if what_to_show(1) == 1

%         Case1 = plot(T_step, Case1_transformIRFs_base_variab(i)*Case1_IRFs_rswmethod_base_variab(i,:), 'k ', 'Linewidth', 1), hold on
        Case1 = plot(Case1_transformIRFs_base_variab(i)*Case1_IRFs_rswmethod_bands_base_variab(i,:,1),             'k -', 'Linewidth', 1), hold on
                plot(Case1_transformIRFs_base_variab(i)*Case1_IRFs_rswmethod_bands_base_variab(i,:,2),             'k -', 'Linewidth', 1), hold on
%         Case1 = fill([T_step,fliplr(T_step)],[Case1_transformIRFs_base_variab(i)*Case1_IRFs_rswmethod_bands_base_variab(i,:,2), ...
%                                        fliplr(Case1_transformIRFs_base_variab(i)*Case1_IRFs_rswmethod_bands_base_variab(i,:,1))], ...
%                                        red,'EdgeColor','none', 'FaceAlpha', 0.5), hold on

    if i == 1
       legendwhat = [legendwhat, Case1];
       legendinfo = [legendinfo; legend_regimesshown(1)];
       lgd = legend(legendwhat, legendinfo, 'Location', 'southeast')
    end
    
end


% % % Case 2
if what_to_show(2) == 1
              
        if what_to_show(1) == 1
        else
            Case2 = plot(T_step, Case2_transformIRFs_base_variab(i)*Case2_IRFs_rswmethod_base_variab(i,:), 'k - ', 'Linewidth', 2), hold on
        end
%         Case2 = plot(Case2_transformIRFs_base_variab(i)*Case2_IRFs_rswmethod_bands_base_variab(i,:,1),             'k -'), hold on
%                 plot(Case2_transformIRFs_base_variab(i)*Case2_IRFs_rswmethod_bands_base_variab(i,:,2),             'k -'), hold on
        Case2 = fill([T_step,fliplr(T_step)],[Case2_transformIRFs_base_variab(i)*Case2_IRFs_rswmethod_bands_base_variab(i,:,2), ...
                                       fliplr(Case2_transformIRFs_base_variab(i)*Case2_IRFs_rswmethod_bands_base_variab(i,:,1))], ...
                                       grey2,'EdgeColor','none', 'FaceAlpha', 0.5), hold on   
                                   
                                   
    if i == 1
       legendwhat = [legendwhat, Case2];
       legendinfo = [legendinfo; legend_regimesshown(2)];
       lgd = legend(legendwhat, legendinfo, 'Location', 'southeast')
    end
    
end

% % % Case 3
if what_to_show(3) == 1
        
%         Case3 = plot(T_step, Case3_transformIRFs_base_variab(i)*Case3_IRFs_rswmethod_base_variab(i,:), 'k -- ', 'Linewidth', 3), hold on
        Case3 = plot(Case3_transformIRFs_base_variab(i)*Case3_IRFs_rswmethod_bands_base_variab(i,:,1),             'k -.'), hold on
                plot(Case3_transformIRFs_base_variab(i)*Case3_IRFs_rswmethod_bands_base_variab(i,:,2),             'k -.'), hold on
%         Case3 = fill([T_step,fliplr(T_step)],[Case3_transformIRFs_base_variab(i)*Case3_IRFs_rswmethod_bands_base_variab(i,:,2), ...
%                                        fliplr(Case3_transformIRFs_base_variab(i)*Case3_IRFs_rswmethod_bands_base_variab(i,:,1))], ...
%                                        grey2,'EdgeColor','none', 'FaceAlpha', 0.5), hold on 

    if i == 1
       legendwhat = [legendwhat, Case3];
       legendinfo = [legendinfo; legend_regimesshown(3)];
       lgd = legend(legendwhat, legendinfo, 'Location', 'best')%, legend('boxoff') 
    end                               
                               
end
                           

    if i >= (ceil(k_base/2)-1)*2+1
       xlabel('months', 'Interpreter','latex') 
    end
    axis tight
    set(gca,'box','off')
    title(names_IRFs_base_variab(i), 'Interpreter','latex'),
    ylabel(labelIRFs_base_variab(i), 'Interpreter','latex')
end
set(gcf,'Position',[0 0 850*.8 400*1.3]) % baseline IRFs
movegui('northwest')
set(gcf, 'PaperPositionMode', 'auto');    


%% IRF figure for the marginal variables
legendwhat = [];
legendinfo = [];

place_legend = 1;

figure(202)
for add = 1:n_added_variab
    
if Figure_numb == 2 || Figure_numb == 5 || Figure_numb == 6  || Figure_numb == 8  
    subplot(ceil(n_added_variab/3),3,add) 
elseif Figure_numb == 7
    subplot(n_added_variab,1,add) 
elseif Figure_numb == 3 || Figure_numb == 4
    subplot(ceil(n_added_variab/2),2,add) 
end


plot(T_step, zeros(T_irf,1), 'k'), hold on
   
% % % Case 1
if what_to_show(1) == 1
   
%          Case1 = plot(T_step, Case1_transformIRFs_all_variab(Case1_k_base+1,add)*Case1_IRFs_rswmethod_all_variab(Case1_k_base+1,:,add), 'k ', 'Linewidth', 1), hold on
        Case1 = plot(T_step, Case1_transformIRFs_all_variab(Case1_k_base+1,add)*Case1_IRFs_rswmethod_bands_all_variab(Case1_k_base+1,:,1,add),             'k -'), hold on
                plot(T_step, Case1_transformIRFs_all_variab(Case1_k_base+1,add)*Case1_IRFs_rswmethod_bands_all_variab(Case1_k_base+1,:,2,add),             'k -'  ), hold on
%          Case1 = fill([T_step,fliplr(T_step)],[Case1_transformIRFs_all_variab(Case1_k_base+1,add)*Case1_IRFs_rswmethod_bands_all_variab(Case1_k_base+1,:,2,add), ...
%                                         fliplr(Case1_transformIRFs_all_variab(Case1_k_base+1,add)*Case1_IRFs_rswmethod_bands_all_variab(Case1_k_base+1,:,1,add))], ...
%                                         grey,'EdgeColor','none', 'FaceAlpha', 0.5), hold on

    if add == place_legend
       legendwhat = [legendwhat, Case1];
       legendinfo = [legendinfo; legend_regimesshown(1)];
       lgd = legend(legendwhat, legendinfo, 'Location', 'best')
    end
end


% % % Case 2
if what_to_show(2) == 1 

        if what_to_show(1) == 1
        else
            Case2 = plot(T_step, Case2_transformIRFs_all_variab(Case2_k_base+1,add)*Case2_IRFs_rswmethod_all_variab(Case2_k_base+1,:,add), 'k ', 'Linewidth', 2), hold on
        end
%         Case2 = plot(T_step, Case2_transformIRFs_all_variab(Case2_k_base+1,add)*Case2_IRFs_rswmethod_bands_all_variab(Case2_k_base+1,:,1,add),             '- k'), hold on
%                 plot(T_step, Case2_transformIRFs_all_variab(Case2_k_base+1,add)*Case2_IRFs_rswmethod_bands_all_variab(Case2_k_base+1,:,2,add),             '- k'), hold on
        Case2 = fill([T_step,fliplr(T_step)],[Case2_transformIRFs_all_variab(Case2_k_base+1,add)*Case2_IRFs_rswmethod_bands_all_variab(Case2_k_base+1,:,2,add), ...
                                       fliplr(Case2_transformIRFs_all_variab(Case2_k_base+1,add)*Case2_IRFs_rswmethod_bands_all_variab(Case2_k_base+1,:,1,add))], ...
                                       grey2,'EdgeColor','none', 'FaceAlpha', 0.5), hold on
                                   
    if add == place_legend
       legendwhat = [legendwhat, Case2];
       legendinfo = [legendinfo; legend_regimesshown(2)];
       lgd = legend(legendwhat, legendinfo, 'Location', 'best')%, legend('boxoff') 
    end    
end                               

% % % Case 3
if what_to_show(3) == 1 

%         Case3 = plot(T_step, Case3_transformIRFs_all_variab(Case3_k_base+1,add)*Case3_IRFs_rswmethod_all_variab(Case3_k_base+1,:,add), 'k ', 'Linewidth', 1), hold on
        Case3 = plot(T_step, Case3_transformIRFs_all_variab(Case3_k_base+1,add)*Case3_IRFs_rswmethod_bands_all_variab(Case3_k_base+1,:,1,add), '-. k'), hold on
                plot(T_step, Case3_transformIRFs_all_variab(Case3_k_base+1,add)*Case3_IRFs_rswmethod_bands_all_variab(Case3_k_base+1,:,2,add), '-. k'), hold on
%          Case3 = fill([T_step,fliplr(T_step)],[Case3_transformIRFs_all_variab(Case3_k_base+1,add)*Case3_IRFs_rswmethod_bands_all_variab(Case3_k_base+1,:,2,add), ...
%                                         fliplr(Case3_transformIRFs_all_variab(Case3_k_base+1,add)*Case3_IRFs_rswmethod_bands_all_variab(Case3_k_base+1,:,1,add))], ...
%                                         grey,'EdgeColor','none', 'FaceAlpha', 0.5), hold on
    
                
        if add == place_legend
           legendwhat = [legendwhat, Case3];
           legendinfo = [legendinfo; legend_regimesshown(3)];
           lgd = legend(legendwhat, legendinfo, 'Location', 'best')%, 
        end
    
end

if Figure_numb == 2 || Figure_numb == 5 || Figure_numb == 6 || Figure_numb == 8
    title(region_all_variab(k_base+1, add), 'Interpreter','latex'),
else
    title(names_IRFs_all_variab(k_base+1, add), 'Interpreter','latex'),
end    
    ylabel(labelIRFs_all_variab(k_base+1, add), 'Interpreter','latex')
        
    axis tight
    set(gca,'box','off')

end
if Figure_numb == 3
    set(gcf,'Position',[0 0 850*.8 600*1.3]) 
elseif Figure_numb == 2 || Figure_numb == 5 || Figure_numb == 6 || Figure_numb == 8
    set(gcf,'Position',[0 0 850*.8 650*1.3]) 
elseif Figure_numb == 7 
    set(gcf,'Position',[0 0 600*.8 400*1.3]) 
else 
    set(gcf,'Position',[0 0 850*.8 400*1.3]) 
end
movegui('northeast')


%% Peak effects of marginal variables

if Figure_numb == 2 || Figure_numb == 5 || Figure_numb == 6 || Figure_numb == 7 

model_series_peaks  = [];
model_seriesL_peaks = [];
model_seriesH_peaks = [];
model_when_peaks    = [];

legendinfo = [];

% % % Case 1
if what_to_show(1) == 1
    model_series_peaks  = [model_series_peaks,  Case1_peak_effects];
    model_seriesL_peaks = [model_seriesL_peaks, Case1_peak_effects_bounds(:,1)];
    model_seriesH_peaks = [model_seriesH_peaks, Case1_peak_effects_bounds(:,2)];
    model_when_peaks    = [model_when_peaks,    Case1_peak_effects_when'];
    
    legendinfo = [legendinfo; legend_regimesshown(1)];
end

% % % Case 2
if what_to_show(2) == 1
    model_series_peaks  = [model_series_peaks,  Case2_peak_effects];
    model_seriesL_peaks = [model_seriesL_peaks, Case2_peak_effects_bounds(:,1)];
    model_seriesH_peaks = [model_seriesH_peaks, Case2_peak_effects_bounds(:,2)];
    model_when_peaks    = [model_when_peaks,    Case2_peak_effects_when'];
    
    legendinfo = [legendinfo; legend_regimesshown(2)];
end

% % % Case 3
if what_to_show(3) == 1
    model_series_peaks  = [model_series_peaks,  Case3_peak_effects];
    model_seriesL_peaks = [model_seriesL_peaks, Case3_peak_effects_bounds(:,1)];
    model_seriesH_peaks = [model_seriesH_peaks, Case3_peak_effects_bounds(:,2)];
    model_when_peaks    = [model_when_peaks,    Case3_peak_effects_when'];

    legendinfo = [legendinfo; legend_regimesshown(3)];
end


figure(203)

    % bar charts
h = bar(model_series_peaks);

h(1).FaceColor = grey;
if size(model_series_peaks,2)>1
    h(2).FaceColor = 'w';
end

h(1).LineStyle = '-';
if size(model_series_peaks,2)>1
    h(2).LineStyle = '-';
end

set(h,'BarWidth',1);    
set(gca,'YGrid','on')
set(gca,'GridLineStyle','-')
lh = legend(h, legendinfo);

set(lh,'Location','Southeast','Orientation','horizontal','AutoUpdate','off'), legend('boxoff')

hold on;

% error bounds
num_variab = size(model_series_peaks, 1); 
num_cases = size(model_series_peaks, 2); 
groupwidth = min(0.8, num_cases/(num_cases+1.5));
for i = 1:num_cases
      % Based on barweb.m by Bolu Ajiboye from MATLAB File Exchange
      x = (1:num_variab) - groupwidth/2 + (2*i-1) * groupwidth / (2*num_cases);  % Aligning error bar with individual bar
      errorbar(x, model_series_peaks(:,i), -model_series_peaks(:,i)+model_seriesL_peaks(:,i), -model_series_peaks(:,i)+model_seriesH_peaks(:,i), 'color', grey2, 'linestyle', 'none');
end

set(gca, 'xTick', [1:1:n_added_variab])
if Figure_numb == 2 || Figure_numb == 5 || Figure_numb == 6
    set(gca,'xticklabel', region_all_variab(k_base+1, :))
else
end
set(gca,'XTickLabelRotation',45)
set(gca,'box','off')
ylabel(labelIRFs_all_variab(k_base+1, num_variab))
set(gcf,'Position',[0 0 950*.7 380*.7])
movegui('south')
set(gcf, 'PaperPositionMode', 'auto');

end


%% Cross country comparison

if Figure_numb == 8

load('..\Temporary\Temporary_Country_Classification')

for panel = 1:2

    if panel == 1
        % TOP PANEL, ORDER PEAK EFFECTS BY AVERAGE TRADE BALANCE
        classif_number = 5; 
        countries_classif_summary(classif_number)
        exclude_Case2 = char('LUX', 'MAL'); exclude_Case2 = cellstr(exclude_Case2); 
        exclude_Case3 = char('CYP'); exclude_Case3 = cellstr(exclude_Case3);
        xlabel_scatter = char('Average trade balance (%)'); 

    elseif panel == 2
        % BOTTOM PANEL, ORDER PEAK EFFECTS BY IP VARIATIONS
        classif_number = 4;
        countries_classif_summary(classif_number)
        exclude_Case2 = char('MAL', 'IRE'); exclude_Case2 = cellstr(exclude_Case2);
        exclude_Case3 = char('CYP', 'IRE'); exclude_Case3 = cellstr(exclude_Case3);
        xlabel_scatter = char('IP variation (%)')
        
    end
    
% %%% Case 2
    peak_effects_show_Case2 = Case2_peak_effects(1:18);

    classif_use = NaN*ones(length(peak_effects_show_Case2),1);
    step_labels = NaN*ones(length(peak_effects_show_Case2),1);
    for i = 1:length(peak_effects_show_Case2)
        j = find(strcmp(countries_name, region_all_variab(k_base+1, i))); 
        classif_use(i) = countries_classif(j,classif_number);   
        step_labels(i) = j;
    end
    countries_label_use = countries_label(step_labels);

    % select the ones for which the classification variable is available
    step1 = isnan(classif_use) == 0;
    classif_use        = classif_use(step1);
    peak_effects_show_Case2_use = peak_effects_show_Case2(step1);
    countries_label_use = countries_label_use(step1);

    % fitted line 
    X = [ones(length(classif_use),1),classif_use];
    
    [beta,bint,r,rint] = regress(peak_effects_show_Case2_use,X,0.1) ;
    yhat_Case2_preexlude = X*beta ; 

    step_exclude_Case2 = NaN*ones(size(exclude_Case2,1),1);
    for i = 1:size(exclude_Case2,1)
        step_exclude_Case2(i) = find(strcmp(countries_label_use, exclude_Case2(i)));
    end
    step_include_Case2 = setdiff([1:1:size(countries_label_use,1)],step_exclude_Case2)

    [beta,bint,r,rint] = regress(peak_effects_show_Case2_use(step_include_Case2),X(step_include_Case2,:),0.1) ;
    yhat_Case2 = X*beta ; 

% %%% Case 3
    peak_effects_show_Case3 = Case3_peak_effects(1:18);

    classif_use = NaN*ones(length(peak_effects_show_Case3),1);
    step_labels = NaN*ones(length(peak_effects_show_Case3),1);
    for i = 1:length(peak_effects_show_Case3)
        j = find(strcmp(countries_name, region_all_variab(k_base+1, i))); 
        classif_use(i) = countries_classif(j,classif_number);   
        step_labels(i) = j;
    end
    countries_label_use = countries_label(step_labels);

    % select the ones for which the classification variable is available
    step1 = isnan(classif_use) == 0;
    classif_use        = classif_use(step1);
    peak_effects_show_Case3_use = peak_effects_show_Case3(step1);
    countries_label_use = countries_label_use(step1);

    % fitted line 
    X = [ones(length(classif_use),1),classif_use] ;

    [beta,bint,r,rint] = regress(peak_effects_show_Case3_use,X,0.1) ;
    yhat_Case3_preexlude = X*beta ; 
        
    step_exclude_Case3 = NaN*ones(size(exclude_Case3,1),1);
    for i = 1:size(exclude_Case3,1)
        step_exclude_Case3(i) = find(strcmp(countries_label_use, exclude_Case3(i)));
    end
    step_include_Case3 = setdiff([1:1:size(countries_label_use,1)],step_exclude_Case3);

    [beta,bint,r,rint] = regress(peak_effects_show_Case3_use(step_include_Case3),X(step_include_Case3,:),0.1) ;
    yhat_Case3 = X*beta ;  

    % Figures
    if panel == 1
        figure(204)
    elseif panel == 2
        figure(205)
    end   
    
        subplot(1,2,1)
    scatter(classif_use,peak_effects_show_Case2_use, 5, 'MarkerEdgeColor', 'k', 'MarkerFaceColor', 'b'), hold on
    for i = 1:length(peak_effects_show_Case2_use)
        if  length(intersect(i,step_exclude_Case2)) 
            text(classif_use(i), peak_effects_show_Case2_use(i), char(countries_label_use(i)), 'color', grey2, 'FontAngle','italic', 'FontSize', 8) 
        else        
            text(classif_use(i), peak_effects_show_Case2_use(i), char(countries_label_use(i)), 'color', 'k', 'FontAngle','italic', 'FontSize', 8) 
        end
    end
    ylabel('Peak effect (% points)', 'Interpreter','latex')
    xlabel(xlabel_scatter, 'Interpreter','latex')
    title('Phase 1', 'Interpreter','latex')
    hold on
    axis tight
    plot(classif_use,yhat_Case2, 'color', grey2), hold off ;

        subplot(1,2,2)
    scatter(classif_use,peak_effects_show_Case3_use, 5, 'MarkerEdgeColor', 'k', 'MarkerFaceColor', 'b'), hold on
    for i = 1:length(peak_effects_show_Case3_use)
        if length(intersect(i,step_exclude_Case3)) 
            text(classif_use(i), peak_effects_show_Case3_use(i), char(countries_label_use(i)), 'color', grey2, 'FontAngle','italic', 'FontSize', 8) 
        else        
            text(classif_use(i), peak_effects_show_Case3_use(i), char(countries_label_use(i)), 'color', 'k', 'FontAngle','italic', 'FontSize', 8) 
        end
    end
    ylabel('Peak effect (% points)', 'Interpreter','latex')
    xlabel(xlabel_scatter, 'Interpreter','latex')
    title('Phase 2', 'Interpreter','latex')
    hold on
    axis tight
    plot(classif_use,yhat_Case3, 'color', grey2), hold off ;

    set(gcf,'Position',[0 0 900*.7 340*.7])
    if panel == 1
        movegui('north')
    elseif panel == 2
        movegui('south')
    end
    set(gcf, 'PaperPositionMode', 'auto');

end

end
