function [Ahat_bootstr_kilian, Ahat_determ_bootstr_kilian] = zFC_VARbootstrap_Kilian2(Y,p,constantD,trendD,trendBreaks,seasonD,moreBreaks,k,Loops)



% Michele Piffer, m.b.piffer@gmail.com
% https://sites.google.com/site/michelepiffereconomics/
% October 2018, Queen Mary, University of London


% Estimate the first VAR
[Ahat_step1, Resid_step1, ~, Ahat_determ_step1, X_determ_step1, T_used, ~, ~, ~] = ...
               zFC_VAR_Estimation3(Y,p,constantD,trendD,trendBreaks,seasonD,moreBreaks) ;

                
                
companion = [Ahat_step1; kron(eye(p-1,p-1),eye(k)),zeros(k*(p-1),k)];
[V, C] = eig(companion);
dominant_root = max(max(abs(C))) ;


% Estimate the bias and the bias corrected parameters
if dominant_root <1

    Yinit               = Y(:,1:p);
    Ahat_average        = zeros(k,k*p);
    Ahat_determ_average = zeros(k,constantD+trendD+seasonD);

    for l = 1:(Loops/2)  
        extract      = unidrnd(T_used,T_used,1)';
        Resid_pseudo = Resid_step1(:,extract);

        % Generate pseudo data
        Y_pseudo = zFC_GenerateVARData(Yinit, Ahat_step1, Resid_pseudo, Ahat_determ_step1, X_determ_step1);

        % Estimate the VAR on the pseudo data
        [Ahat_loop, ~, ~, Ahat_determ_loop, ~, ~, ~, ~, ~] = ...
                   zFC_VAR_Estimation3(Y_pseudo,p,constantD,trendD,trendBreaks,seasonD,moreBreaks);

        Ahat_average        = Ahat_average        +  Ahat_loop*1/(Loops/2);   
        Ahat_determ_average = Ahat_determ_average +  Ahat_determ_loop*1/(Loops/2);   
    end
    Ahat_bias        = Ahat_average        - Ahat_step1;
    Ahat_determ_bias = Ahat_determ_average - Ahat_determ_step1;


    delta_vec          = [0 : 0.01 : 1];
    dominant_root_step = 1.1;
    d                  = length(delta_vec);

    while dominant_root_step >= 1
        delta = delta_vec(d);
        Ahat_biascorrect        = Ahat_step1        - delta*Ahat_bias;
        Ahat_determ_biascorrect = Ahat_determ_step1 - delta*Ahat_determ_bias;

        companion = [Ahat_biascorrect; kron(eye(p-1,p-1),eye(k)),zeros(k*(p-1),k)];
        [V, C] = eig(companion);
        dominant_root_step = max(max(abs(C)));
        d     = d-1;
    end

elseif dominant_root >= 1
  
    Ahat_bias        = zeros(k,k*p);
    Ahat_determ_bias = zeros(k,constantD+trendD+seasonD);
    
    Ahat_biascorrect        = Ahat_step1;
    Ahat_determ_biascorrect = Ahat_determ_step1;
    
    delta = 0;
 
end

% Use the bias corrected parameters for a new bootstrap

Yinit                      = Y(:,1:p);
Ahat_bootstr_kilian        = NaN*ones(k,k*p,Loops);
Ahat_determ_bootstr_kilian = NaN*ones(k,constantD+trendD+seasonD,Loops);

for l = 1:Loops  
   extract = unidrnd(T_used,T_used,1)';
   Resid_pseudo = Resid_step1(:,extract);

   % Generate pseudo data
   Y_pseudo = zFC_GenerateVARData(Yinit, Ahat_biascorrect, Resid_pseudo, Ahat_determ_biascorrect, X_determ_step1);

   % Estimate the VAR on the pseudo data
   [Ahat_loop, ~, ~, Ahat_determ_loop, ~, ~, ~, ~, ~] = ...
                   zFC_VAR_Estimation3(Y_pseudo,p,constantD,trendD,trendBreaks,seasonD,moreBreaks);

   Ahat_bootstr_kilian(:,:,l)        = Ahat_loop        - delta*Ahat_bias;   
   Ahat_determ_bootstr_kilian(:,:,l) = Ahat_determ_loop - delta*Ahat_determ_bias;
end

    

end